@@ -53,7 +53,8 @@ def compute_counts(  # noqa MC0001  # nosec
         Where the Cmd datatype has a name attribute (command name) and
         a params attribute (dict with the params and values associated
         with the command)
-        an example session:
+        an example session::
+
             [
                 Cmd(
                     name='Set-User',
@@ -64,6 +65,7 @@ def compute_counts(  # noqa MC0001  # nosec
                     params={'Identity': 'blahblah', 'AuditEnabled': 'false'}
                 )
             ]
+
     start_token: str
         dummy command to signify the start of a session (e.g. "##START##")
     end_token: str
@@ -107,9 +109,10 @@ def compute_counts(  # noqa MC0001  # nosec
                 pars = dict.fromkeys(pars)
             for par, val in pars.items():
                 param_counts[par] += 1
-                value_counts[val] += 1
                 cmd_param_counts[cmd.name][par] += 1
-                param_value_counts[par][val] += 1
+                if val:
+                    value_counts[val] += 1
+                    param_value_counts[par][val] += 1
         seq2_counts[prev][end_token] += 1
         seq1_counts[end_token] += 1
 
@@ -279,10 +282,12 @@ def compute_prob_setofparams_given_cmd(
         name of command (e.g. for Exchange powershell commands: "Set-Mailbox")
     params_with_vals: Union[dict, set]
         dict of accompanying params and values for the cmd
-        e.g for Exchange powershell commands:
+        e.g for Exchange powershell commands::
+
             {'Identity': 'an_identity' , 'ForwardingEmailAddress': 'email@email.com'}
-            If params is set to be a set, then an artificial dictionary will
-            be created with the set as the keys and Nones for the values.
+
+        If params is set to be a set, then an artificial dictionary will
+        be created with the set as the keys and Nones for the values.
     param_cond_cmd_probs: Union[StateMatrix, dict]
         computed probabilities of params conditional on the command
     value_cond_param_probs: Union[StateMatrix, dict]
@@ -350,12 +355,14 @@ def compute_likelihood_window(
     ----------
     window: List[Cmd]
         part or all of a session, where a session is a list the Cmd datatype
-        an example session:
+        an example session::
+
             [
                 Cmd(name='Set-User', params={'Identity': 'blahblah', 'Force': 'true'}),
                 Cmd(name='Set-Mailbox',
                     params={'Identity': 'blahblah', 'AuditEnabled': 'false'})
             ]
+
     prior_probs: Union[StateMatrix, dict]
         computed probabilities of individual commands
     trans_probs: Union[StateMatrix, dict]
@@ -457,7 +464,8 @@ def compute_likelihood_windows_in_session(
     ----------
     session: List[Cmd]
         list of Cmd datatype
-        an example session:
+        an example session::
+
             [
                 Cmd(
                     name='Set-User',
@@ -468,6 +476,7 @@ def compute_likelihood_windows_in_session(
                     params={'Identity': 'blahblah', 'AuditEnabled': 'false'}
                 )
             ]
+
     prior_probs: Union[StateMatrix, dict]
         computed probabilities of individual commands
     trans_probs: Union[StateMatrix, dict]
@@ -498,24 +507,20 @@ def compute_likelihood_windows_in_session(
     list of likelihoods
 
     """
-    if use_start_end_tokens:
-        if start_token is None or end_token is None:
-            raise MsticpyException(
-                "start_token and end_token should not be set to None when "
-                "use_start_end_tokens is set to True"
-            )
+    if use_start_end_tokens and (start_token is None or end_token is None):
+        raise MsticpyException(
+            "start_token and end_token should not be set to None when "
+            "use_start_end_tokens is set to True"
+        )
 
     likelihoods = []
     sess = session.copy()
     if use_start_end_tokens and end_token:
-        sess += [Cmd(name=str(end_token), params=dict())]
+        sess += [Cmd(name=str(end_token), params={})]
     end = len(sess) - window_len
     for i in range(end + 1):
         window = sess[i : i + window_len]  # noqa E203
-        if i == 0:
-            use_start = use_start_end_tokens
-        else:
-            use_start = False
+        use_start = use_start_end_tokens if i == 0 else False
         lik = compute_likelihood_window(
             window=window,
             prior_probs=prior_probs,
@@ -557,7 +562,8 @@ def rarest_window_session(
     ----------
     session: List[Cmd]
         list of Cmd datatype
-        an example session:
+        an example session::
+
             [
                 Cmd(
                     name='Set-User',
@@ -568,6 +574,7 @@ def rarest_window_session(
                     params={'Identity': 'blahblah', 'AuditEnabled': 'false'}
                 )
             ]
+
     prior_probs: Union[StateMatrix, dict]
         computed probabilities of individual commands
     trans_probs: Union[StateMatrix, dict]
