@@ -27,7 +27,12 @@ from .._version import VERSION
 from .cred_wrapper import CredentialWrapper
 from .exceptions import MsticpyAzureConnectionError
 from ..common import pkg_config as config
-from .cloud_mappings import get_all_endpoints, get_all_suffixes
+from .cloud_mappings import (
+    get_all_endpoints,
+    get_all_suffixes,
+    CLOUD_ALIASES,
+    CLOUD_MAPPING,
+)
 
 __version__ = VERSION
 __author__ = "Pete Bryan"
@@ -36,21 +41,26 @@ __author__ = "Pete Bryan"
 AzCredentials = namedtuple("AzCredentials", ["legacy", "modern"])
 
 
-def default_auth_methods() -> List[str]:
-    """Get the default (all) authentication options."""
+def get_azure_config_value(key, default):
+    """Get a config value from Azure section."""
     try:
         az_settings = config.get_config("Azure")
-        if az_settings and "auth_methods" in az_settings:
-            return az_settings["auth_methods"]
+        if az_settings and key in az_settings:
+            return az_settings[key]
     except KeyError:
         pass  # no Azure section in config
-    return ["env", "cli", "msi", "interactive"]
+    return default
+
+
+def default_auth_methods() -> List[str]:
+    """Get the default (all) authentication options."""
+    return get_azure_config_value("auth_methods", ["cli", "msi", "interactive"])
 
 
 class AzureCloudConfig:
     """Azure Cloud configuration."""
 
-    def __init__(self, cloud: str = None):
+    def __init__(self, cloud: str = None, tenant_id: Optional[str] = None):
         """
         Initialize AzureCloudConfig from `cloud` or configuration.
 
@@ -60,25 +70,39 @@ class AzureCloudConfig:
             The cloud to retrieve configuration for. If not supplied,
             the cloud ID is read from configuration. If this is not available,
             it defaults to 'global'.
+        tenant_id : str, optional
+            The tenant to authenticate against. If not supplied,
+            the tenant ID is read from configuration, or the default tenant
+            for the identity.
 
         """
         if cloud:
             self.cloud = cloud
         else:
-            self.cloud = "global"
-            try:
-                az_settings = config.get_config("Azure")
-                if az_settings and "cloud" in az_settings:
-                    self.cloud = az_settings["cloud"]
-            except KeyError:
-                pass  # no Azure section in config
+            self.cloud = get_azure_config_value("cloud", "global")
+
+        if tenant_id:
+            self.tenant_id = tenant_id
+        else:
+            self.tenant_id = get_azure_config_value("tenant_id", None)
+
         self.auth_methods = default_auth_methods()
-        try:
-            self.auth_methods = config.get_config("Azure").get(
-                "auth_methods", default_auth_methods()
-            )
-        except KeyError:
-            pass  # no Azure section in config
+
+    @property
+    def cloud_names(self) -> List[str]:
+        """Return a list of current cloud names."""
+        return list(CLOUD_MAPPING.keys())
+
+    @staticmethod
+    def resolve_cloud_alias(alias) -> Optional[str]:
+        """Return match of cloud alias or name."""
+        alias_cf = alias.casefold()
+        aliases = {alias.casefold(): cloud for alias, cloud in CLOUD_ALIASES.items()}
+        if alias_cf in aliases:
+            return aliases[alias_cf]
+        if alias_cf in aliases.values():
+            return alias_cf
+        return None
 
     @property
     def endpoints(self) -> azure_cloud.CloudEndpoints:
@@ -123,7 +147,11 @@ class AzureCloudConfig:
 
 
 def _az_connect_core(
-    auth_methods: List[str] = None, cloud: str = None, silent: bool = False, **kwargs
+    auth_methods: List[str] = None,
+    cloud: str = None,
+    tenant_id: str = None,
+    silent: bool = False,
+    **kwargs,
 ) -> AzCredentials:
     """
     Authenticate using multiple authentication sources.
@@ -143,6 +171,9 @@ def _az_connect_core(
         What Azure cloud to connect to.
         By default it will attempt to use the cloud setting from config file.
         If this is not set it will default to Azure Public Cloud
+    tenant_id : str, optional
+        The tenant to authenticate against. If not supplied,
+        the tenant ID is read from configuration, or the default tenant for the identity.
     silent : bool, optional
         Whether to display any output during auth process. Default is False.
 
@@ -174,7 +205,8 @@ def _az_connect_core(
     """
     # Create the auth methods with the specified cloud region
     cloud = cloud or kwargs.pop("region", AzureCloudConfig().cloud)
-    auth_options = _create_auth_options(cloud)
+    tenant_id = tenant_id or AzureCloudConfig().tenant_id
+    auth_options = _create_auth_options(cloud, tenant_id)
     if not auth_methods:
         auth_methods = default_auth_methods()
     try:
@@ -249,8 +281,8 @@ class _AzCachedConnect:
 
 
 # externally callable function using the class above
-_AZ_CACHED_CONNECT = _AzCachedConnect()
-az_connect_core = _AZ_CACHED_CONNECT.connect
+# _AZ_CACHED_CONNECT = _AzCachedConnect()
+az_connect_core = _az_connect_core
 
 
 def only_interactive_cred(chained_cred: ChainedTokenCredential):
@@ -288,7 +320,7 @@ def _filter_all_warnings(record) -> bool:
     return True
 
 
-def _create_auth_options(cloud: str = None) -> dict:
+def _create_auth_options(cloud: str = None, tenant_id: str = None) -> dict:
     """Create auth options dict with correct cloud set."""
     az_config = AzureCloudConfig(cloud)
 
@@ -298,7 +330,9 @@ def _create_auth_options(cloud: str = None) -> dict:
         "env": EnvironmentCredential(),
         "cli": AzureCliCredential(),
         "msi": ManagedIdentityCredential(),
-        "interactive": InteractiveBrowserCredential(authority=aad_uri),
+        "interactive": InteractiveBrowserCredential(
+            authority=aad_uri, tenant_id=tenant_id
+        ),
     }
 
 
