@@ -65,13 +65,15 @@ class MsticpyUserError(MsticpyException):
 
         Other Parameters
         ----------------
-        title : str
+        title : str, optional
             If a `title` keyword argument is supplied it will be used
             to create the title line.
-        *_uri : str
+        *_uri : str, optional
             Additional keyword arguments who's names end in "_uri"
             will be used to create a list of references in addition to
             the primary `help_uri`
+        display : bool, optional
+            Display the exception when created. By default, True
 
         Notes
         -----
@@ -95,6 +97,7 @@ class MsticpyUserError(MsticpyException):
             Union[str, Tuple[str, str], Tuple[Tuple[str, str], str]]
         ] = []
         title = kwargs.pop("title", "we've hit an error while running")
+        disp_exception = kwargs.pop("display", True)
         self._output.append((f"{self.__class__.__name__} - {title}", "title"))
 
         self._output.extend(args)
@@ -111,7 +114,7 @@ class MsticpyUserError(MsticpyException):
             self._output.append("You can find other related help here:")
             for uri in help_args:
                 self._output.append((uri, "uri"))
-        if _get_config("msticpy.FriendlyExceptions"):
+        if _get_config("msticpy.FriendlyExceptions") and disp_exception:
             self._display_exception()
 
         # add the extra elements to the the exception standard args.
@@ -354,7 +357,7 @@ class MsticpyKqlConnectionError(MsticpyUserError):
     """Exception class for KqlConnection errors."""
 
     DEF_HELP_URI = (
-        "Connecting to Azure Sentinel",
+        "Connecting to Microsoft Sentinel",
         "https://msticpy.readthedocs.io/en/latest/data_acquisition/DataProviders.html"
         + "#connecting-to-an-azure-sentinel-workspace",
     )
@@ -399,10 +402,40 @@ class MsticpyImportExtraError(MsticpyUserError, ImportError):
 
 
 class MsticpyAzureConnectionError(MsticpyUserError):
-    """Exception class for KqlConnection errors."""
+    """Exception class for Azure Connection errors."""
 
     DEF_HELP_URI = (
-        "Connecting to Azure Sentinel",
+        "Connecting to Microsoft Sentinel",
         "https://msticpy.readthedocs.io/en/latest/data_acquisition/AzureData.html"
         + "#instantiating-and-connecting-with-an-azure-data-connector",
     )
+
+
+class MsticpyParameterError(MsticpyUserError):
+    """Exception class for missing/incorrect parameters."""
+
+    DEF_HELP_URI = ("MSTICPy documentation", "https://msticpy.readthedocs.io")
+
+    def __init__(
+        self, *args, help_uri: Union[Tuple[str, str], str, None] = None, **kwargs
+    ):
+        """
+        Create parameter exception.
+
+        Parameters
+        ----------
+        help_uri : Union[Tuple[str, str], str, None], optional
+            Override the default help URI.
+        parameters : Union[str, List[str]
+            The name of the bad parameter(s).
+
+        """
+        parameter = kwargs.pop("parameter", None)
+        if not parameter:
+            raise AttributeError("Keyword argument 'parameter' must be supplied")
+        mssg = "One or more parameters were incorrect."
+        if isinstance(parameter, str):
+            parameter = [parameter]
+        add_args = [*args, mssg, ", ".join(parameter)]
+        uri = help_uri or self.DEF_HELP_URI
+        super().__init__(*add_args, help_uri=uri, **kwargs)
