@@ -16,6 +16,7 @@ Custom settings are accessible as an attribute `custom_settings`.
 Consolidated settings are accessible as an attribute `settings`.
 
 """
+from importlib.util import find_spec
 import os
 from pathlib import Path
 from typing import Any, Dict, Optional, Callable
@@ -149,7 +150,7 @@ def _read_config_file(config_file: str) -> Dict[str, Any]:
 
     """
     if Path(config_file).is_file():
-        with open(config_file) as f_handle:
+        with open(config_file, "r", encoding="utf-8") as f_handle:
             # use safe_load instead of load
             try:
                 return yaml.safe_load(f_handle)
@@ -278,6 +279,8 @@ def validate_config(mp_config: Dict[str, Any] = None, config_file: str = None):
         "OpenPageRank",
         "GeoIPLite",
         "IPStack",
+        "RiskIQ",
+        "IntSights",
     ]
     for conf_section in ["TIProviders", "OtherProviders", _DP_KEY]:
         prov_errors, prov_warn = _check_provider_settings(
@@ -298,21 +301,28 @@ def validate_config(mp_config: Dict[str, Any] = None, config_file: str = None):
 
 def _print_validation_report(mp_errors, mp_warn):
     if mp_errors:
-        title = "\nThe following configuration errors were found:"
-        print(title, "\n", "-" * len(title))
-        for err in mp_errors:
-            print(err)
+        _print_validation_item(
+            "\nThe following configuration errors were found:", mp_errors
+        )
+
     else:
         print("No errors found.")
     if mp_warn:
-        title = "\nThe following configuration warnings were found:"
-        print(title, "\n", "-" * len(title))
-        for err in mp_warn:
-            print(err)
+        _print_validation_item(
+            "\nThe following configuration warnings were found:", mp_warn
+        )
+
     else:
         print("No warnings found.")
 
 
+def _print_validation_item(arg0, arg1):
+    title = arg0
+    print(title, "\n", "-" * len(title))
+    for err in arg1:
+        print(err)
+
+
 def _validate_azure_sentinel(mp_config):
     mp_errors = []
     mp_warnings = []
@@ -351,8 +361,11 @@ def _check_provider_settings(mp_config, section, key_provs):
         if "Args" not in p_setting:
             continue
         sec_args = p_setting.get("Args")
-        if not sec_args:
-            mp_errors.append(f"'{section}/{p_name}/{sec_args}' key has no settings.")
+        if not sec_args or not isinstance(sec_args, dict):
+            mp_errors.append(
+                f"'{section}/{p_name}/{sec_args}' key has no settings or "
+                + "is not a valid format."
+            )
             continue
         sec_path = f"{section}/{p_name}" if section else f"{p_name}"
         mp_errors.extend(
@@ -386,7 +399,9 @@ def _check_required_provider_settings(sec_args, sec_path, p_name, key_provs):
         errs.append(_check_required_key(sec_args, "clientId", sec_path))
         errs.append(_check_required_key(sec_args, "tenantId", sec_path))
         errs.append(_check_required_key(sec_args, "clientSecret", sec_path))
-
+    if p_name == "RiskIQ":
+        errs.append(_check_required_key(sec_args, "ApiID", sec_path))
+        errs.append(_check_required_package("passivetotal", sec_path))
     return [err for err in errs if err]
 
 
@@ -396,6 +411,12 @@ def _check_required_key(conf_section, key, sec_path):
     return None
 
 
+def _check_required_package(package, sec_path):
+    if find_spec(package) is None:
+        return f"{sec_path}: Required package '{package}' is not installed."
+    return None
+
+
 def _check_is_uuid(conf_section, key, sec_path):
     if (
         key not in conf_section
@@ -413,7 +434,7 @@ def _check_env_vars(args_key, section):
     for val in args_key.values():
         if not val:
             continue
-        if "EnvironmentVar" in val:
+        if isinstance(val, dict) and "EnvironmentVar" in val:
             env_name = val.get("EnvironmentVar")
             if not env_name:
                 mp_errs.append(f"{section}: No environment variable name specified.")
