@@ -14,12 +14,23 @@ import uuid
 import warnings
 from enum import Enum
 from pathlib import Path
-from typing import Any, Callable, Dict, Iterable, List, Optional, Tuple, Union
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    Tuple,
+    Type,
+    TypeVar,
+    Union,
+)
 from platform import python_version
 
 import pkg_resources
 from IPython import get_ipython
-from IPython.core.display import HTML, display, DisplayHandle
+from IPython.display import HTML, display, DisplayHandle
 from tqdm.auto import tqdm
 from tqdm.notebook import tqdm as tqdm_notebook
 
@@ -94,9 +105,7 @@ def check_py_version(min_ver: Tuple = (3, 6)):
     if sys.version_info < min_ver:
         print("Check the Kernel->Change Kernel menu and ensure that Python 3.6")
         print("or later is selected as the active kernel.")
-        raise SystemExit(
-            "Python %s.%s or later is required.\n" % (min_ver[0], min_ver[1])
-        )
+        raise SystemExit(f"Python {min_ver[0]}.{min_ver[1]} or later is required.\n")
 
 
 @export
@@ -128,7 +137,7 @@ def resolve_pkg_path(part_path: str):
 
 # pylint: disable=not-an-iterable, too-many-branches
 @export  # noqa: MC0001
-def check_and_install_missing_packages(
+def check_and_install_missing_packages(  # noqa: MC0001
     required_packages: List[str],
     force_notebook: bool = False,
     user: bool = False,
@@ -205,9 +214,9 @@ def check_and_install_missing_packages(
                     stderr=subprocess.PIPE,
                 )
             except subprocess.CalledProcessError as proc_err:
-                print(f"An Error has occured while installing {package}.")
-                print(f"Output: {str(proc_err.stdout)}")
-                print(f"Errs: {str(proc_err.stderr)}")
+                print(f"An Error has occurred while installing {package}.")
+                print(f"Output: {proc_err.stdout}")
+                print(f"Errs: {proc_err.stderr}")
                 pkg_success = False
         print(f"{package} installed.")
 
@@ -329,10 +338,16 @@ _F_STYLES = {
 
 
 @export
-def is_ipython() -> bool:
+def is_ipython(notebook: bool = False) -> bool:
     """
     Return True if running in IPython environment.
 
+    Parameters
+    ----------
+    notebook : bool, optional
+        If notebook is true this will only return true if running
+        in a Jupyter notebook.
+
     Returns
     -------
     bool
@@ -340,7 +355,9 @@ def is_ipython() -> bool:
         otherwise False
 
     """
-    return bool(get_ipython())
+    if not notebook:
+        return bool(get_ipython())
+    return get_ipython() and type(get_ipython()).__name__.startswith("ZMQ")
 
 
 def check_kwarg(arg_name: str, legal_args: List[str]):
@@ -488,16 +505,41 @@ def valid_pyname(identifier: str) -> str:
     return identifier
 
 
-def enum_parse(enum_cls: type, value: str) -> Optional[Enum]:
-    """Try to parse a string value to an Enum member."""
-    if not issubclass(enum_cls, Enum):
+# Define generic type so enum_parse returns the same type as
+# passed in 'enum_class
+EnumType = TypeVar("EnumType")
+
+
+def enum_parse(enum_cls: Type[EnumType], value: str) -> Optional[EnumType]:
+    """
+    Try to parse a string value to an Enum member.
+
+    Parameters
+    ----------
+    enum_cls : EnumType
+        The Enum type to check against
+    value : str
+        The enum value to parse
+
+    Returns
+    -------
+    Optional[EnumType]
+        The enumeration value matching `value` or None
+
+    Raises
+    ------
+    TypeError
+        If something other than an Enum subclass is passed.
+
+    """
+    if not issubclass(enum_cls, Enum):  # type: ignore
         raise TypeError("Can only be used with classes derived from enum.Enum.")
-    if value in enum_cls.__members__:
-        return enum_cls.__members__[value]
+    if value in enum_cls.__members__:  # type: ignore
+        return enum_cls.__members__[value]  # type: ignore
     val_lc = value.casefold()
-    val_map = {name.casefold(): name for name in enum_cls.__members__}
+    val_map = {name.casefold(): name for name in enum_cls.__members__}  # type: ignore
     if val_lc in val_map:
-        return enum_cls.__members__[val_map[val_lc]]
+        return enum_cls.__members__[val_map[val_lc]]  # type: ignore
     return None
 
 
