@@ -35,7 +35,7 @@ _RESOURCES = [
 ]
 
 _NO_CONFIG_WARN = [
-    "Could not find Azure Sentinel settings in msticpyconfig.yaml or a config.json ",
+    "Could not find Microsoft Sentinel settings in msticpyconfig.yaml or a config.json ",
     "(in the current directory or via a MSTICPYCONFIG variable.)",
     "We found the file '{config_file}' and will use this.",
     "We recommend using an explicit msticpyconfig.yaml specified using the",
@@ -54,7 +54,7 @@ _NO_CONFIG_WARN = [
 _NO_CONFIG_ERR = [
     "Could not find msticpyconfig.yaml or config.json.",
     "The 'config.json' file is created when you launch notebooks from "
-    "Azure Sentinel. If you have copied the notebook to another location "
+    "Microsoft Sentinel. If you have copied the notebook to another location "
     "or folder you will need to copy this configuration file.",
     "Alternatively, we recommend using an explicit msticpyconfig.yaml"
     "and adding your Workspace and Tenant IDs to that file.",
@@ -83,6 +83,9 @@ class WorkspaceConfig:
 
     PKG_CONF_TENANT_KEY = "TenantId"
     PKG_CONF_WS_KEY = "WorkspaceId"
+    PKG_CONF_SUB_KEY = "SubscriptionId"
+    PKG_CONF_RES_GROUP_KEY = "ResourceGroup"
+    PKG_CONF_NAME_KEY = "WorkspaceName"
 
     CONF_WS_ID_KEY = "workspace_id"
     CONF_TENANT_ID_KEY = "tenant_id"
@@ -230,7 +233,7 @@ class WorkspaceConfig:
         if not file_path:
             return {}
         try:
-            with open(file_path) as json_file:
+            with open(file_path, "r", encoding="utf-8") as json_file:
                 if json_file:
                     return json.load(json_file)
         except json.JSONDecodeError:
@@ -261,10 +264,10 @@ class WorkspaceConfig:
 
     def prompt_for_ws(self):
         """Display an interactive prompt for Workspace details."""
-        md_warn("No Azure Sentinel configuration found.")
+        md_warn("No Microsoft Sentinel configuration found.")
         md(
             "Please enter the workspace ID and tenant Id"
-            + " to allow connection to the Azure Sentinel workspace."
+            + " to allow connection to the Microsoft Sentinel workspace."
         )
         ws_id_wgt = widgets.Text(description="Workspace Id:", **WIDGET_DEFAULTS)
         ten_id_wgt = widgets.Text(description="Tenant Id:", **WIDGET_DEFAULTS)
@@ -286,7 +289,7 @@ class WorkspaceConfig:
                 "data_acquisition/DataProviders.html#"
                 "connecting-to-an-azure-sentinel-workspace' "
                 "target='_blank' rel='noopener noreferrer'>"
-                "Connecting to an Azure Sentinel Workspace</a>"
+                "Connecting to a Microsoft Sentinel Workspace</a>"
             ),
         )
 
@@ -314,6 +317,18 @@ class WorkspaceConfig:
             self._config[self.CONF_TENANT_ID_KEY] = selected_workspace.get(
                 self.PKG_CONF_TENANT_KEY
             )
+        if self.PKG_CONF_SUB_KEY in selected_workspace:
+            self._config[self.CONF_SUB_ID_KEY] = selected_workspace.get(
+                self.PKG_CONF_SUB_KEY
+            )
+        if self.PKG_CONF_RES_GROUP_KEY in selected_workspace:
+            self._config[self.CONF_RES_GROUP_KEY] = selected_workspace.get(
+                self.PKG_CONF_RES_GROUP_KEY
+            )
+        if self.PKG_CONF_NAME_KEY in selected_workspace:
+            self._config[self.CONF_WS_NAME_KEY] = selected_workspace.get(
+                self.PKG_CONF_NAME_KEY
+            )
         return {}
 
     def _search_for_file(self, pattern: str) -> Optional[str]:
