@@ -7,7 +7,7 @@
 from typing import Any, Dict, Optional, Tuple, Union
 
 import ipywidgets as widgets
-import requests
+import httpx
 
 from ..common.azure_auth_core import AzureCloudConfig
 from .comp_edit import SettingsControl
@@ -28,12 +28,12 @@ SETTING_LIST_LAYOUT = {
     "style": {"description_width": "100px"},
 }
 
-_TEXT_LAYOUT = {
+TEXT_LAYOUT = {
     "layout": widgets.Layout(width="70%"),
     "style": {"description_width": "100px"},
 }
 
-_TEXT_AREA_LAYOUT = {
+TEXT_AREA_LAYOUT = {
     "layout": widgets.Layout(width="70%"),
     "style": {"description_width": "100px"},
 }
@@ -47,7 +47,6 @@ if _DEBUG:
             return
         print(*args)
 
-
 else:
 
     def print_debug(*args):
@@ -179,7 +178,7 @@ def get_def_tenant_id(sub_id: str) -> Optional[str]:
     get_tenant_url = (
         f"{res_mgmt_uri}/subscriptions/{{subscriptionid}}" + "?api-version=2015-01-01"
     )
-    resp = requests.get(get_tenant_url.format(subscriptionid=sub_id))
+    resp = httpx.get(get_tenant_url.format(subscriptionid=sub_id))
     # Tenant ID is returned in the WWW-Authenticate header/Bearer authorization_uri
     www_header = resp.headers.get("WWW-Authenticate")
     if not www_header:
@@ -301,7 +300,7 @@ def get_wgt_ctrl(
             ctrl = widgets.Checkbox(
                 description=var_name,
                 value=py_to_widget(curr_val, val_type=st_type),
-                **(wgt_style or _TEXT_LAYOUT),
+                **(wgt_style or TEXT_LAYOUT),
             )
         elif st_type == "enum":
             ctrl = widgets.Select(
@@ -326,7 +325,7 @@ def get_wgt_ctrl(
             ctrl = widgets.Textarea(
                 description=var_name,
                 value=py_to_widget(curr_val, val_type="list") or "",
-                **(wgt_style or _TEXT_AREA_LAYOUT),
+                **(wgt_style or TEXT_AREA_LAYOUT),
                 # tooltip="Enter each item as 'key:value'. Separate items with new lines.",
             )
             setattr(ctrl, "tag", "list")
@@ -334,7 +333,7 @@ def get_wgt_ctrl(
             ctrl = widgets.Text(
                 description=var_name,
                 value=py_to_widget(curr_val, val_type=st_type),
-                **(wgt_style or _TEXT_AREA_LAYOUT),
+                **(wgt_style or TEXT_AREA_LAYOUT),
                 # tooltip="Enter items (no quotes) on separate lines.",
             )
         mp_controls.set_control(var_path, ctrl)
