@@ -9,7 +9,7 @@ import os
 import re
 import warnings
 from datetime import datetime
-from typing import Any, Dict, Iterable, Optional, Tuple, Union
+from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
 
 import pandas as pd
 from IPython import get_ipython
@@ -24,12 +24,14 @@ from ...common.exceptions import (
 )
 from ...common.wsconfig import WorkspaceConfig
 from ...common.utility import export
+from ..query_defns import DataEnvironment
 from .driver_base import DriverBase, QuerySource
 
 try:
     from Kqlmagic import kql as kql_exec
     from Kqlmagic.kql_engine import KqlEngineError
     from Kqlmagic.kql_response import KqlError
+    from Kqlmagic.kql_proxy import KqlResponse
     from Kqlmagic.my_aad_helper import AuthenticationError
 except ImportError as imp_err:
     raise MsticpyImportExtraError(
@@ -61,6 +63,9 @@ _LOGANALYTICS_URL_BY_CLOUD = {
 }
 
 
+# pylint: disable=too-many-instance-attributes
+
+
 @export
 class KqlDriver(DriverBase):
     """KqlDriver class to execute kql queries."""
@@ -82,7 +87,7 @@ class KqlDriver(DriverBase):
         """
         self._ip = get_ipython()
         self._debug = kwargs.get("debug", False)
-        super().__init__()
+        super().__init__(**kwargs)
 
         self.formatters = {"datetime": self._format_datetime, "list": self._format_list}
         self._loaded = self._is_kqlmagic_loaded()
@@ -92,7 +97,7 @@ class KqlDriver(DriverBase):
             self._load_kql_magic()
 
         self._schema: Dict[str, Any] = {}
-
+        self.environment = kwargs.get("data_environment", DataEnvironment.MSSentinel)
         self.kql_cloud, self.az_cloud = self._set_kql_cloud()
 
         if connection_str:
@@ -116,25 +121,38 @@ class KqlDriver(DriverBase):
         mp_az_auth : Union[bool, str, list, None], optional
             Optional parameter directing KqlMagic to use MSTICPy Azure authentication.
             Values can be:
-
-            - True or "default": use the settings in msticpyconfig.yaml 'Azure' section
-            - auth_method: single auth method name ('msi', 'cli', 'env' or 'interactive')
-            - auth_methods: list of acceptable auth methods from ('msi', 'cli',
-              'env' or 'interactive')
+            True or "default": use the settings in msticpyconfig.yaml 'Azure' section
+            str: single auth method name ('msi', 'cli', 'env' or 'interactive')
+            List[str]: list of acceptable auth methods from ('msi', 'cli',
+            'env' or 'interactive')
+        mp_az_tenant_id: str, optional
+            Optional parameter specifying a Tenant ID for use by MSTICPy Azure
+            authentication.
 
         """
-        print("Connecting...", end=" ")
+        if not self._previous_connection:
+            print("Connecting...", end=" ")
+
+        mp_az_auth = kwargs.pop("mp_az_auth", "default")
+        mp_az_tenant_id = kwargs.pop("mp_az_tenant_id", None)
+
         if isinstance(connection_str, WorkspaceConfig):
+            if not mp_az_tenant_id and "tenant_id" in connection_str:
+                mp_az_tenant_id = connection_str["tenant_id"]
             connection_str = connection_str.code_connect_str
+
         if not connection_str:
             raise MsticpyKqlConnectionError(
-                "A connection string is needed to connect to Azure Sentinel.",
+                f"A connection string is needed to connect to {self._connect_target}",
                 title="no connection string",
             )
         if "kqlmagic_args" in kwargs:
             connection_str = connection_str + " " + kwargs["kqlmagic_args"]
-        if "mp_az_auth" in kwargs and "try_token" not in kwargs:
-            self._set_az_auth_option(kwargs["mp_az_auth"])
+        # Default to using Azure Auth if possible.
+
+        if mp_az_auth and "try_token" not in kwargs:
+            self._set_az_auth_option(mp_az_auth, mp_az_tenant_id)
+
         self.current_connection = connection_str
         kql_err_setting = self._get_kql_option("short_errors")
         self._connected = False
@@ -143,7 +161,8 @@ class KqlDriver(DriverBase):
             if self._ip is not None:
                 try:
                     kql_exec(connection_str)
-                    print("connected")
+                    if not self._previous_connection:
+                        print("connected")
                 except KqlError as ex:
                     self._raise_kql_error(ex)
                 except KqlEngineError as ex:
@@ -153,6 +172,7 @@ class KqlDriver(DriverBase):
                 except Exception as ex:  # pylint: disable=broad-except
                     self._raise_adal_error(ex)
                 self._connected = True
+                self._previous_connection = True
                 self._schema = self._get_schema()
             else:
                 print(f"Could not connect to kql query provider for {connection_str}")
@@ -195,7 +215,6 @@ class KqlDriver(DriverBase):
             the underlying provider result if an error.
 
         """
-        del kwargs
         if query_source:
             try:
                 table = query_source["args.table"]
@@ -207,14 +226,16 @@ class KqlDriver(DriverBase):
                 if table not in self.schema:
                     raise MsticpyNoDataSourceError(
                         f"The table {table} for this query is not in your workspace",
-                        " schema. Please check your workspace",
+                        " or database schema. Please check your this",
                         title=f"{table} not found.",
                     )
-        data, result = self.query_with_results(query)
+        data, result = self.query_with_results(query, **kwargs)
         return data if data is not None else result
 
     # pylint: disable=too-many-branches
-    def query_with_results(self, query: str, **kwargs) -> Tuple[pd.DataFrame, Any]:
+    def query_with_results(
+        self, query: str, **kwargs
+    ) -> Tuple[pd.DataFrame, KqlResponse]:
         """
         Execute query string and return DataFrame of results.
 
@@ -230,20 +251,12 @@ class KqlDriver(DriverBase):
             Kql ResultSet.
 
         """
-        # connect or switch the connection if our connection string
-        # is not the current KqlMagic connection.
-        if not self.connected and self.current_connection:
-            self.connect(self.current_connection)
-        if not self.connected:
-            raise MsticpyNotConnectedError(
-                "Please run the connect() method before running a query.",
-                title="not connected to a workspace.",
-                help_uri=MsticpyKqlConnectionError.DEF_HELP_URI,
-            )
-
-        if self._debug:
+        debug = kwargs.pop("debug", self._debug)
+        if debug:
             print(query)
 
+        self._make_current_connection()
+
         # save current auto_dataframe setting so that we can set to false
         # and restore current setting
         auto_dataframe = self._get_kql_option(option="auto_dataframe")
@@ -258,24 +271,32 @@ class KqlDriver(DriverBase):
         if result is not None:
             if isinstance(result, pd.DataFrame):
                 return result, None
-            if (
-                hasattr(result, "completion_query_info")
-                and result.completion_query_info["StatusCode"] == 0
+            if hasattr(result, "completion_query_info") and (
+                int(result.completion_query_info.get("StatusCode", 1)) == 0
+                or result.completion_query_info.get("Text")
+                == "Query completed successfully"
             ):
                 data_frame = result.to_dataframe()
                 if result.is_partial_table:
                     print("Warning - query returned partial results.")
+                if debug:
+                    print("Query status:\n", "\n".join(self._get_query_status(result)))
                 return data_frame, result
 
-        # Query failed
-        err_args = []
-        if hasattr(result, "completion_query_info"):
-            err_desc = result.completion_query_info.get("StatusDescription")
-            err_desc = f"StatusDescription {err_desc}"
-            err_code = f"(err_code: {result.completion_query_info.get('StatusCode')})"
-            err_args = [err_desc, err_code]
-        err_args.append(f"Query:\n{query}")
-        raise MsticpyDataQueryError(*err_args)
+        return self._raise_query_failure(query, result)
+
+    def _make_current_connection(self):
+        """Switch to the current connection (self.current_connection)."""
+        try:
+            self.connect(self.current_connection)
+        except MsticpyKqlConnectionError:
+            self._connected = False
+        if not self.connected:
+            raise MsticpyNotConnectedError(
+                "Please run the connect() method before running a query.",
+                title=f"not connected to a {self._connect_target}",
+                help_uri=MsticpyKqlConnectionError.DEF_HELP_URI,
+            )
 
     def _load_kql_magic(self):
         """Load KqlMagic if not loaded."""
@@ -294,6 +315,16 @@ class KqlDriver(DriverBase):
             return self._ip.find_magic("kql") is not None
         return bool(kql_exec("--version"))
 
+    @property
+    def _connect_target(self) -> str:
+        if self.environment == DataEnvironment.MSSentinel:
+            return "Workspace"
+        return "Kusto cluster"
+
+    @staticmethod
+    def _get_query_status(result) -> List[str]:
+        return [f"{key}: '{value}'" for key, value in result.completion_query_info]
+
     @staticmethod
     def _get_schema() -> Dict[str, Dict]:
         return kql_exec("--schema")
@@ -340,6 +371,27 @@ class KqlDriver(DriverBase):
                 fmt_list.append(f"{item}")
         return ",".join(fmt_list)
 
+    @staticmethod
+    def _raise_query_failure(query, result):
+        """Raise query failure exception."""
+        err_contents = []
+        if hasattr(result, "completion_query_info"):
+            q_info = result.completion_query_info
+            if "StatusDescription" in q_info:
+                err_contents = [
+                    f"StatusDescription {q_info.get('StatusDescription')}",
+                    f"(err_code: {result.completion_query_info.get('StatusCode')})",
+                ]
+            elif "Text" in q_info:
+                err_contents = [f"StatusDescription {q_info.get('Text')}"]
+            else:
+                err_contents = [f"Unknown error type: {q_info}"]
+        if not err_contents:
+            err_contents = ["Unknown query error"]
+
+        err_contents.append(f"Query:\n{query}")
+        raise MsticpyDataQueryError(*err_contents)
+
     _WS_RGX = r"workspace\(['\"](?P<ws>[^'\"]+)"
     _TEN_RGX = r"tenant\(['\"](?P<tenant>[^'\"]+)"
 
@@ -347,7 +399,7 @@ class KqlDriver(DriverBase):
         kql_err = json.loads(ex.args[0]).get("error")
         if kql_err.get("code") == "WorkspaceNotFoundError":
             ex_mssgs = [
-                "The workspace ID used to connect to Azure Sentinel could not be found.",
+                "The workspace ID used to connect to Microsoft Sentinel could not be found.",
                 "Please check that this is a valid workspace for your subscription",
             ]
             ws_match = re.search(self._WS_RGX, self.current_connection, re.IGNORECASE)
@@ -398,7 +450,8 @@ class KqlDriver(DriverBase):
         """Raise an authentication error."""
         ex_mssgs = [
             "The authentication failed.",
-            "Please check the credentials you are using and permissions on the workspace",
+            "Please check the credentials you are using and permissions on the ",
+            "workspace or cluster.",
             *(ex.args),
         ]
         raise MsticpyKqlConnectionError(*ex_mssgs, title="authentication failed")
@@ -409,13 +462,12 @@ class KqlDriver(DriverBase):
         raise MsticpyKqlConnectionError(
             "Another exception was returned by the service",
             *ex.args,
-            f"Full exception:\n{str(ex)}",
+            f"Full exception:\n{ex}",
             title="connection failed",
         )
 
     def _set_az_auth_option(
-        self,
-        mp_az_auth: Union[bool, str, list, None],
+        self, mp_az_auth: Union[bool, str, list, None], mp_az_tenant_id: str = None
     ):
         """
         Build connection string with auth elements.
@@ -429,9 +481,11 @@ class KqlDriver(DriverBase):
             - auth_method: single auth method name ('msi', 'cli', 'env' or 'interactive')
             - auth_methods: list of acceptable auth methods from ('msi', 'cli',
                 'env' or 'interactive')
+        mp_az_tenant_id: str, optional
+            Optional parameter specifying a Tenant ID for use by MSTICPy Azure
+            authentication.
 
         """
-        print("Authenticating to Azure.")
         # default to default auth methods
         az_config = AzureCloudConfig()
         auth_types = az_config.auth_methods
@@ -441,19 +495,22 @@ class KqlDriver(DriverBase):
         elif isinstance(mp_az_auth, list):
             auth_types = mp_az_auth
         # get current credentials
-        creds = az_connect(auth_methods=auth_types)
+        creds = az_connect(auth_methods=auth_types, tenant_id=mp_az_tenant_id)
         if only_interactive_cred(creds.modern):
             print("Check your default browser for interactive sign-in prompt.")
 
-        la_uri = _LOGANALYTICS_URL_BY_CLOUD[self.az_cloud]
-        la_token_uri = f"{la_uri}.default"
-        # obtain token for Log Analytics
-        token = creds.modern.get_token(la_token_uri)
+        endpoint_uri = self._get_endpoint_uri()
+        endpoint_token_uri = f"{endpoint_uri}.default"
+        # obtain token for the endpoint
+        token = creds.modern.get_token(endpoint_token_uri)
         # set the token values in the namespace
 
-        la_token = {
+        endpoint_token = {
             "access_token": token.token,
             "token_type": "Bearer",
-            "resource": la_uri,
+            "resource": endpoint_uri,
         }
-        self._set_kql_option("try_token", la_token)
+        self._set_kql_option("try_token", endpoint_token)
+
+    def _get_endpoint_uri(self):
+        return _LOGANALYTICS_URL_BY_CLOUD[self.az_cloud]
