@@ -24,7 +24,7 @@ class LocalDataDriver(DriverBase):
 
     def __init__(self, connection_str: str = None, **kwargs):
         """
-        Instantiaite LocalDataDriver and optionally connect.
+        Instantiate LocalDataDriver and optionally connect.
 
         Parameters
         ----------
@@ -36,7 +36,7 @@ class LocalDataDriver(DriverBase):
         """
         del connection_str
         self._debug = kwargs.get("debug", False)
-        super().__init__()
+        super().__init__(**kwargs)
 
         # If data paths specified, use these
         data_paths = kwargs.get("data_paths")
@@ -50,6 +50,7 @@ class LocalDataDriver(DriverBase):
         self._schema: Dict[str, Any] = {}
         self._loaded = True
         self._connected = True
+        self.current_connection = "; ".join(self._paths)
 
     def _get_data_paths(self) -> Dict[str, str]:
         """Read files in data paths."""
