@@ -3,19 +3,19 @@
 # Licensed under the MIT License. See License.txt in the project root for
 # license information.
 # --------------------------------------------------------------------------
-"""."""
+"""Mordor/OTRF Security datasets driver."""
 import json
+import pickle  # nosec
 import zipfile
 from collections import defaultdict
 from datetime import datetime
-from json import JSONDecodeError
 from pathlib import Path
 from typing import Any, Dict, Generator, Iterable, List, Optional, Set, Tuple, Union
 from zipfile import BadZipFile, ZipFile
 
 import attr
 import pandas as pd
-import requests
+import httpx
 import yaml
 from tqdm.auto import tqdm
 
@@ -30,7 +30,7 @@ __author__ = "Ian Hellen"
 
 
 _MORDOR_TREE_URI = (
-    "https://api.github.com/repos/OTRF/mordor/git/trees/master?recursive=1"
+    "https://api.github.com/repos/OTRF/Security-Datasets/git/trees/master?recursive=1"
 )
 
 _MITRE_JSON_URL = (
@@ -43,6 +43,10 @@ _MTR_TECH_CAT_URI = "https://attack.mitre.org/techniques/{cat}/"
 MITRE_TECHNIQUES: pd.DataFrame = None
 MITRE_TACTICS: pd.DataFrame = None
 
+_MITRE_TECH_CACHE = "mitre_tech_cache.pkl"
+_MITRE_TACTICS_CACHE = "mitre_tact_cache.pkl"
+_MORDOR_CACHE = "mordor_cache.json"
+
 
 # pylint: disable=too-many-instance-attributes
 class MordorDriver(DriverBase):
@@ -67,6 +71,7 @@ class MordorDriver(DriverBase):
         self.save_folder = kwargs.pop(
             "save_folder", mdr_settings.get("save_folder", ".")
         )
+        self.save_folder = _resolve_cache_folder(self.save_folder)
         self.silent = kwargs.pop("silent", False)
 
         self._loaded = True
@@ -84,15 +89,19 @@ class MordorDriver(DriverBase):
 
         """
         global MITRE_TECHNIQUES, MITRE_TACTICS
+        cache_folder = self.save_folder if self.use_cached else None
         print("Retrieving Mitre data...")
 
         if MITRE_TECHNIQUES is None or MITRE_TACTICS is None:
-            MITRE_TECHNIQUES, MITRE_TACTICS = _get_mitre_categories()
+            MITRE_TECHNIQUES, MITRE_TACTICS = _get_mitre_categories(
+                cache_folder=cache_folder
+            )
         self.mitre_techniques = MITRE_TECHNIQUES
         self.mitre_tactics = MITRE_TACTICS
 
         print("Retrieving Mordor data...")
-        self.mordor_data = _GET_MORDOR_METADATA()
+
+        self.mordor_data = _GET_MORDOR_METADATA(cache_folder=cache_folder)
         self.mdr_idx_tech, self.mdr_idx_tact = _build_mdr_indexes(self.mordor_data)
 
         self._connected = True
@@ -136,6 +145,7 @@ class MordorDriver(DriverBase):
             raise self._create_not_connected_err()
         use_cached = kwargs.pop("used_cached", self.use_cached)
         save_folder = kwargs.pop("save_folder", self.save_folder)
+        save_folder = _resolve_cache_folder(save_folder)
         silent = kwargs.pop("silent", self.silent)
         result_df = download_mdr_file(
             file_uri=query,
@@ -259,6 +269,14 @@ class MordorDriver(DriverBase):
         )
 
 
+def _resolve_cache_folder(cache_path: str):
+    """Expand and optionally creates cache folder."""
+    cache_folder = Path(cache_path).expanduser()
+    if not cache_folder.is_dir():
+        cache_folder.mkdir(parents=True, exist_ok=True)
+    return str(cache_folder)
+
+
 # pylint: enable=too-many-instance-attributes
 
 
@@ -412,7 +430,7 @@ def _to_datetime(date_val) -> datetime:
         return datetime.min
 
 
-DS_PREFIX = "https://raw.githubusercontent.com/OTRF/mordor/master/datasets/"
+DS_PREFIX = "https://raw.githubusercontent.com/OTRF/Security-Datasets/master/datasets/"
 
 
 # pylint: disable=not-an-iterable, no-member
@@ -424,9 +442,11 @@ class MordorEntry:
 
     title: str
     id: str
-    author: str
+    type: str
     creation_date: datetime = attr.ib(converter=_to_datetime)
     modification_date: datetime = attr.ib(converter=_to_datetime)
+    contributors: List[str] = attr.Factory(list)
+    author: Optional[str] = None
     platform: Optional[str] = None
     description: Optional[str] = None
     tags: List[str] = attr.Factory(list)
@@ -520,11 +540,12 @@ def get_mdr_data_paths(item_type="metadata") -> Generator[str, None, None]:
 
     """
     md_tree = _GET_MORDOR_TREE(_MORDOR_TREE_URI)
-    prefix = f"datasets/{item_type}"
     yield from (
         t_item["path"]
         for t_item in md_tree.get("tree")
-        if t_item["type"] == "blob" and t_item["path"].startswith(prefix)
+        if t_item["type"] == "blob"
+        and t_item["path"].startswith("datasets")
+        and item_type in t_item["path"]
     )
 
 
@@ -535,7 +556,7 @@ def _get_mdr_github_tree():
     def _get_mdr_tree(uri):
         nonlocal mordor_tree
         if mordor_tree is None:
-            resp = requests.get(uri)
+            resp = httpx.get(uri)
             mordor_tree = resp.json()
         return mordor_tree
 
@@ -548,18 +569,20 @@ _GET_MORDOR_TREE = _get_mdr_github_tree()
 
 def _get_mdr_file(gh_file):
     """Fetch a file from Mordor repo."""
-    file_blob_uri = f"https://raw.githubusercontent.com/OTRF/mordor/master/{gh_file}"
-    file_resp = requests.get(file_blob_uri)
+    file_blob_uri = (
+        f"https://raw.githubusercontent.com/OTRF/Security-Datasets/master/{gh_file}"
+    )
+    file_resp = httpx.get(file_blob_uri)
     return file_resp.content
 
 
 def _create_mdr_metadata_cache():
     md_metadata: Dict[str, MordorEntry] = {}
 
-    def _get_mdr_metadata():
+    def _get_mdr_metadata(cache_folder: Optional[str] = None):
         nonlocal md_metadata
         if not md_metadata:
-            md_metadata = _fetch_mdr_metadata()
+            md_metadata = _fetch_mdr_metadata(cache_folder=cache_folder)
         return md_metadata
 
     return _get_mdr_metadata
@@ -568,12 +591,20 @@ def _create_mdr_metadata_cache():
 # Create closure
 _GET_MORDOR_METADATA = _create_mdr_metadata_cache()
 
+_LAST_UPDATE_KEY = "mp_last_updated"
+_DEFAULT_TS = pd.Timestamp(pd.Timestamp.utcnow() - pd.Timedelta(days=60))
+
 
 # pylint: disable=global-statement
-def _fetch_mdr_metadata() -> Dict[str, MordorEntry]:
+def _fetch_mdr_metadata(cache_folder: Optional[str] = None) -> Dict[str, MordorEntry]:
     """
     Return full metadata for Mordor datasets.
 
+    Parameters
+    ----------
+    cache_folder : Optional[str]
+        Folder to search for mordor cache, by default None
+
     Returns
     -------
     Dict[str, MordorEntry]:
@@ -584,20 +615,61 @@ def _fetch_mdr_metadata() -> Dict[str, MordorEntry]:
 
     if MITRE_TECHNIQUES is None or MITRE_TACTICS is None:
         MITRE_TECHNIQUES, MITRE_TACTICS = _get_mitre_categories()
-
     md_metadata: Dict[str, MordorEntry] = {}
+
+    md_cached_metadata = _read_mordor_cache(cache_folder)
     mdr_md_paths = list(get_mdr_data_paths("metadata"))
-    for y_file in tqdm(mdr_md_paths, unit=" files", desc="Downloading Mordor metadata"):
-        gh_file_content = _get_mdr_file(y_file)
-        yaml_doc = yaml.safe_load(gh_file_content)
-        doc_id = yaml_doc.get("id")
-        md_metadata[doc_id] = MordorEntry(**yaml_doc)
+    for filename in tqdm(
+        mdr_md_paths, unit=" files", desc="Downloading Mordor metadata"
+    ):
+        cache_valid = False
+        if filename in md_cached_metadata:
+            metadata_doc = md_cached_metadata[filename]
+            last_timestamp = pd.Timestamp(
+                metadata_doc.get(_LAST_UPDATE_KEY, _DEFAULT_TS)
+            )
+            cache_valid = (pd.Timestamp.utcnow() - last_timestamp).days < 30
+
+        if not cache_valid:
+            gh_file_content = _get_mdr_file(filename)
+            try:
+                metadata_doc = yaml.safe_load(gh_file_content)
+            except yaml.error.YAMLError:
+                continue
+            metadata_doc[_LAST_UPDATE_KEY] = pd.Timestamp.utcnow().isoformat()
+            md_cached_metadata[filename] = metadata_doc
+        doc_id = metadata_doc.get("id")
+        mdr_entry = metadata_doc.copy()
+        mdr_entry.pop(_LAST_UPDATE_KEY, None)
+        md_metadata[doc_id] = MordorEntry(**mdr_entry)
+
+    _write_mordor_cache(md_cached_metadata, cache_folder)
     return md_metadata
 
 
 # pylint: enable=global-statement
 
 
+def _read_mordor_cache(cache_folder) -> Dict[str, Any]:
+    """Return dictionary of cached metadata if cached_folder is a valid path."""
+    md_cached_metadata: Dict[str, Any] = {}
+    mordor_cache = Path(cache_folder).joinpath(_MORDOR_CACHE)
+    if _valid_cache(mordor_cache):
+        try:
+            md_json = Path(mordor_cache).read_text(encoding="utf-8")
+            md_cached_metadata = json.loads(md_json)
+        except json.JSONDecodeError:
+            pass
+    return md_cached_metadata
+
+
+def _write_mordor_cache(md_cached_metadata, cache_folder):
+    """Write dictionary of cached metadata if cached_folder is a valid path."""
+    mordor_cache = Path(cache_folder).joinpath(_MORDOR_CACHE)
+    json_text = json.dumps(md_cached_metadata, indent=4)
+    Path(mordor_cache).write_text(json_text, encoding="utf-8")
+
+
 def _build_mdr_indexes(
     mdr_metadata: Dict[str, MordorEntry]
 ) -> Tuple[Dict[str, Set[str]], Dict[str, Set[str]]]:
@@ -662,10 +734,10 @@ def download_mdr_file(
     save_file = Path(save_folder).joinpath(save_path)
     if not use_cached or not save_file.is_file():
         # streamed download
-        resp = requests.get(file_uri, stream=True)
         with open(str(save_file), "wb") as fdesc:
-            for chunk in resp.iter_content(chunk_size=1024):
-                fdesc.write(chunk)
+            with httpx.stream("GET", file_uri) as resp:
+                for chunk in resp.iter_bytes(chunk_size=1024):
+                    fdesc.write(chunk)
 
     try:
         with zipfile.ZipFile(str(save_file)) as zip_file:
@@ -734,28 +806,6 @@ def _extract_zip_file_to_df(  # noqa: MC0001
     return out_df
 
 
-def _json_to_df(file_path, silent):
-    errs = []
-    with open(str(file_path), "r") as j_file:
-        j_text = j_file.read()
-    df_list = []
-    if silent:
-        line_gen = enumerate(j_text.split("\n"))
-    else:
-        line_gen = tqdm(enumerate(j_text.split("\n")), "lines")
-    for line_num, line in line_gen:
-        if not line:
-            continue
-        try:
-            df_list.append(json.loads(line))
-        except JSONDecodeError:
-            errs.append(f"Could not parse #{line_num}: '{line}'")
-    out_df = pd.DataFrame(df_list)
-    if errs:
-        print(f"{len(errs)} errors detected", errs)
-    return out_df
-
-
 def search_mdr_data(
     mdr_data: Dict[str, MordorEntry], terms: str = None, subset: Iterable[str] = None
 ) -> Set[str]:
@@ -833,14 +883,16 @@ def _reshape_mitre_df(data):
     )
 
 
-def _get_mitre_categories() -> Tuple[pd.DataFrame, pd.DataFrame]:
+def _get_mitre_categories(
+    cache_folder: Optional[str] = None,
+) -> Tuple[pd.DataFrame, pd.DataFrame]:
     """
     Download and return Mitre techniques and tactics.
 
     Parameters
     ----------
-    uri_template : str
-        URI to fetch MITRE category from.
+    cache_folder : Optional[str]
+        Folder to search for mordor cache, by default None
 
     Returns
     -------
@@ -849,7 +901,17 @@ def _get_mitre_categories() -> Tuple[pd.DataFrame, pd.DataFrame]:
         descriptions.
 
     """
-    resp = requests.get(_MITRE_JSON_URL)
+    if cache_folder:
+        tech_cache = Path(cache_folder).joinpath(_MITRE_TECH_CACHE)
+        tactics_cache = Path(cache_folder).joinpath(_MITRE_TACTICS_CACHE)
+        if _valid_cache(tech_cache) and _valid_cache(tactics_cache):
+            try:
+                tech_df = pd.read_pickle(tech_cache)
+                tactics_df = pd.read_pickle(tactics_cache)
+                return tech_df, tactics_df
+            except pickle.PickleError:
+                pass
+    resp = httpx.get(_MITRE_JSON_URL)
     mitre = pd.json_normalize(resp.json()["objects"])
 
     # remove deprecated items
@@ -858,5 +920,16 @@ def _get_mitre_categories() -> Tuple[pd.DataFrame, pd.DataFrame]:
 
     tech_df = _reshape_mitre_df(mitre[mitre.type == "attack-pattern"])
     tactics_df = _reshape_mitre_df(mitre[mitre.type == "x-mitre-tactic"])
+    if cache_folder:
+        tech_df.to_pickle(tech_cache)
+        tactics_df.to_pickle(tactics_cache)
 
     return tech_df, tactics_df
+
+
+def _valid_cache(path: Path, expired_days=30):
+    """Return True if the file exists and is younger than `expired_days`."""
+    if not path.is_file():
+        return False
+    days_old = (datetime.now() - datetime.fromtimestamp(path.stat().st_mtime)).days
+    return days_old < expired_days
