@@ -40,7 +40,7 @@ SPLUNK_CONNECT_ARGS = {
     "port": "(integer) The port number (the default is 8089).",
     "http_scheme": "('https' or 'http') The scheme for accessing the service "
     + "(the default is 'https').",
-    "verify": "(Boolean) Enable (True) or disable (False) SSL verrification for "
+    "verify": "(Boolean) Enable (True) or disable (False) SSL verification for "
     + "https connections. (optional, the default is True)",
     "owner": "(string) The owner context of the namespace (optional).",
     "app": "(string) The app context of the namespace (optional).",
@@ -68,7 +68,7 @@ class SplunkDriver(DriverBase):
 
     def __init__(self, **kwargs):
         """Instantiate Splunk Driver."""
-        super().__init__()
+        super().__init__(**kwargs)
         self.service = None
         self._loaded = True
         self._connected = False
@@ -377,7 +377,7 @@ class SplunkDriver(DriverBase):
         """Get config from msticpyconfig."""
         data_provs = get_provider_settings(config_section="DataProviders")
         splunk_settings: Optional[ProviderSettings] = data_provs.get("Splunk")
-        return getattr(splunk_settings, "Args", {})
+        return getattr(splunk_settings, "args", {})
 
     @staticmethod
     def _create_not_connected_err():
