@@ -11,8 +11,7 @@ from timeit import default_timer as timer
 from typing import Any, Dict, Optional, Tuple, Union
 
 import pandas as pd
-from requests.exceptions import ConnectionError as ConnError
-from requests.exceptions import HTTPError
+import httpx
 from sumologic.sumologic import SumoLogic
 
 from ..._version import VERSION
@@ -59,7 +58,7 @@ class SumologicDriver(DriverBase):
 
     def __init__(self, **kwargs):
         """Instantiate Sumologic Driver."""
-        super().__init__()
+        super().__init__(**kwargs)
         self.service = None
         self._loaded = True
         self._connected = False
@@ -103,14 +102,14 @@ class SumologicDriver(DriverBase):
                 accessKey=arg_dict["accesskey"],
                 endpoint=arg_dict["connection_str"],
             )
-        except ConnError as err:
+        except httpx.ConnectError as err:
             raise MsticpyConnectionError(
                 f"Authentication error connecting to Sumologic: {err}",
                 title="Sumologic connection",
                 help_uri=_HELP_URI,
                 nb_uri=_SL_NB_URI,
             ) from err
-        except HTTPError as err:
+        except httpx.HTTPError as err:
             raise MsticpyConnectionError(
                 f"Communication error connecting to Sumologic: {err}",
                 title="Sumologic connection",
@@ -125,7 +124,7 @@ class SumologicDriver(DriverBase):
                 nb_uri=_SL_NB_URI,
             ) from err
         self._connected = True
-        print("connected with accessid {}".format(arg_dict["accessid"]))
+        print(f"connected with accessid {arg_dict['accessid']}")
 
     def _get_connect_args(
         self, connection_str: Optional[str], **kwargs
@@ -133,9 +132,10 @@ class SumologicDriver(DriverBase):
         """Check and consolidate connection parameters."""
         cs_dict: Dict[str, Any] = self._CONNECT_DEFAULTS
         # Fetch any config settings
-        cs_dict.update(self._get_config_settings())
+        settings, cs_is_instance_name = self._get_config_settings(connection_str)
+        cs_dict.update(settings)
         # If a connection string - parse this and add to config
-        if connection_str:
+        if connection_str and not cs_is_instance_name:
             cs_dict["connection_str"] = connection_str
         if kwargs:
             # if connection args supplied as kwargs
@@ -172,23 +172,35 @@ class SumologicDriver(DriverBase):
 
         Other Parameters
         ----------------
-        kwargs :
-            Are passed to Sumologic
-            days: Search the past X days.
-            start_time: A datetime() object representing the start of the search
-                    window. If used without end_time, the end of the search
-                    window is the current time.
-            end_time: A datetime() object representing the end of the search window.
-                  If used without start_time, the search start will be the earliest
-                  time in the index.
-            timezone: timezone used for time range search
-            byreceipttime:  if time reference should used _receiptTime (time when Sumologic
-                        got message) instead of _messageTime (time present in log message).
-            limit: An integer describing the max number of search results to return.
-            forcemessagesresults: Force results to be raw messages even if aggregated query.
-            verbosity: Provide more verbose state. from 0 least verbose to 4 most one.
-            checkinterval: interval in seconds to check if results are gathered
-            timeout: timeout in seconds when gathering results
+        days : int
+            Search the past X days.
+        start : datetime
+            A datetime() object representing the start of the search
+            window. If used without end_time, the end of the search
+            window is the current time.
+        start_time : datetime
+            alias for `start`
+        end : datetime
+            A datetime() object representing the end of the search window.
+            If used without start_time, the search start will be the earliest
+            time in the index.
+        end_time:
+            alias for `end`
+        timezone : str
+            timezone used for time range search
+        byreceipttime : datetime
+            if time reference should used _receiptTime (time when Sumologic
+            got message) instead of _messageTime (time present in log message).
+        limit : int
+            An integer describing the max number of search results to return.
+        forcemessagesresults : bool
+            Force results to be raw messages even if aggregated query.
+        verbosity : int
+            Provide more verbose state. from 0 least verbose to 4 most one.
+        checkinterval : int
+            interval in seconds to check if results are gathered
+        timeout : int
+            timeout in seconds when gathering results
 
         Returns
         -------
@@ -231,8 +243,8 @@ class SumologicDriver(DriverBase):
 
         qry_count = re.search(r"\|\s*count", query, re.IGNORECASE)
         if verbosity >= 2:
-            print("DEBUG: search job {0}".format(searchjob))
-            print(f"DEBUG: search performance: {str(timer() - timer_start)}")
+            print(f"DEBUG: search job {searchjob}")
+            print(f"DEBUG: search performance: {timer() - timer_start}")
             print(f"DEBUG: messages or records? {qry_count}")
 
         # poll for job completion
@@ -251,7 +263,7 @@ class SumologicDriver(DriverBase):
     def _poll_job_status(self, searchjob, verbosity):
         status = self.service.search_job_status(searchjob)
         if verbosity >= 2:
-            print("DEBUG: status {0}".format(status))
+            print(f"DEBUG: status {status}")
         time_counter = 0
         while status["state"] != "DONE GATHERING RESULTS":
             if status["state"] == "CANCELLED":
@@ -310,7 +322,7 @@ class SumologicDriver(DriverBase):
 
     @staticmethod
     def _raise_qry_except(err: Exception, mssg: str, action: Optional[str] = None):
-        if isinstance(err, HTTPError):
+        if isinstance(err, httpx.HTTPError):
             raise MsticpyConnectionError(
                 f"Communication error connecting to Sumologic: {err}",
                 title=f"Sumologic {mssg}",
@@ -359,27 +371,40 @@ class SumologicDriver(DriverBase):
 
         Other Parameters
         ----------------
-        kwargs :
-            Are passed to Sumologic
-            days: Search the past X days.
-            start_time (or start): A datetime() object representing the start of the search
-                    window. If used without end_time, the end of the search
-                    window is the current time.
-            end_time (or end): A datetime() object representing the end of the search window.
-                  If used without start_time, the search start will be the earliest
-                  time in the index.
-            timeZone: timezone used for time range search
-            byReceiptTime:  if time reference should used _receiptTime (time when Sumologic
-                        got message) instead of _messageTime (time present in log message).
-            limit: An integer describing the max number of search results to return.
-            forceMessagesResults: Force results to be raw messages even if aggregated query.
-            verbosity: Provide more verbose state. from 0 least verbose to 4 most one.
-            normalize: If set to True, fields containing structures (i.e. subfields)
-                   will be flattened such that each field has it's own column in
-                   the dataframe. If False, there will be a single column for the
-                   structure, with a JSON string encoding all the contents.
-            exporting: Export result to file.
-            export_path: file path for exporte results.
+        days: int
+            Search the past X days.
+        start : datetime
+            A datetime() object representing the start of the search
+            window. If used without end_time, the end of the search
+            window is the current time.
+        start_time : datetime
+            alias for `start`
+        end : datetime
+            A datetime() object representing the end of the search window.
+            If used without start_time, the search start will be the earliest
+            time in the index.
+        end_time : datetime
+            alias for `end`
+        timeZone : str
+            timezone used for time range search
+        byReceiptTime : datetime
+            if time reference should used _receiptTime (time when Sumologic
+            got message) instead of _messageTime (time present in log message).
+        limit : int
+            An integer describing the max number of search results to return.
+        forceMessagesResults : bool
+            Force results to be raw messages even if aggregated query.
+        verbosity : int
+            Provide more verbose state. from 0 least verbose to 4 most one.
+        normalize : bool
+            If set to True, fields containing structures (i.e. subfields)
+            will be flattened such that each field has it's own column in
+            the dataframe. If False, there will be a single column for the
+            structure, with a JSON string encoding all the contents.
+        exporting : bool
+            Export result to file.
+        export_path : str
+            file path for exporte results.
 
         Returns
         -------
@@ -442,11 +467,24 @@ class SumologicDriver(DriverBase):
 
     # Read values from configuration
     @staticmethod
-    def _get_config_settings() -> Dict[Any, Any]:
+    def _get_config_settings(instance_name: str = None) -> Tuple[Dict[str, Any], bool]:
         """Get config from msticpyconfig."""
         data_provs = get_provider_settings(config_section="DataProviders")
-        sumologic_settings: Optional[ProviderSettings] = data_provs.get("Sumologic")
-        return getattr(sumologic_settings, "args", {})
+        sl_settings = {
+            name: settings
+            for name, settings in data_provs.items()
+            if name.startswith("Sumologic")
+        }
+        sumologic_settings: Optional[ProviderSettings]
+        # Check if the connection string is an instance name
+        sumologic_settings = sl_settings.get(f"Sumologic-{instance_name}")
+        if sumologic_settings:
+            is_instance_name = True
+        else:
+            # otherwise get the default Sumologic entry
+            sumologic_settings = sl_settings.get("Sumologic")
+            is_instance_name = False
+        return getattr(sumologic_settings, "args", {}), is_instance_name
 
     @staticmethod
     def _create_not_connected_err():
