@@ -6,7 +6,9 @@
 """Query helper definitions."""
 from abc import ABC, abstractmethod
 from enum import Enum
-from typing import Union
+from typing import Union, List
+
+import pandas as pd
 
 from ..common.utility import export
 from .._version import VERSION
@@ -36,6 +38,7 @@ class DataFamily(Enum):
     Splunk = 8
     ResourceGraph = 9
     Sumologic = 10
+    Cybereason = 11
 
     @classmethod
     def parse(cls, value: Union[str, int]) -> "DataFamily":
@@ -83,6 +86,7 @@ class DataEnvironment(Enum):
     Unknown = 0
     AzureSentinel = 1  # alias of LogAnalytics
     LogAnalytics = 1
+    MSSentinel = 1
     Kusto = 2
     AzureSecurityCenter = 3
     SecurityGraph = 4
@@ -93,6 +97,8 @@ class DataEnvironment(Enum):
     Mordor = 8
     ResourceGraph = 9
     Sumologic = 10
+    M365D = 11
+    Cybereason = 12
 
     @classmethod
     def parse(cls, value: Union[str, int]) -> "DataEnvironment":
@@ -144,3 +150,53 @@ class QueryParamProvider(ABC):
 
         """
         return {}
+
+
+def ensure_df_datetimes(
+    data: pd.DataFrame,
+    columns: Union[str, List[str], None] = None,
+    add_utc_tz: bool = True,
+) -> pd.DataFrame:
+    """
+    Return dataframe with converted TZ-aware timestamps.
+
+    Parameters
+    ----------
+    data : pd.DataFrame
+        Input dataframe
+    columns : Union[str, List[str], None], optional
+        column (str) or list of columns to convert, by default None.
+        If this parameter is not supplied then any column containing
+        the substring "time" is used as a candidate for conversion.
+    add_utc_tz: bool, optional
+        If True any datetime columns in the `columns` parameter (
+        (or default `'.*time.*'` columns) that are timezone-naive,
+        will be converted to Timezone-aware timestamps marked as UTC.
+
+    Returns
+    -------
+    pd.DataFrame
+        Converted DataFrame.
+
+    """
+    if not columns:
+        columns = list(data.filter(regex=".*[Tt]ime.*").columns)
+    if isinstance(columns, str):
+        columns = [columns]
+    col_map = {
+        col: "datetime64[ns, UTC]"
+        for col in set(columns)
+        if col in data.columns and not pd.api.types.is_datetime64_any_dtype(data[col])
+    }
+    converted_data = data.astype(col_map, errors="ignore")
+
+    # Look for any TZ-naive columns in the list
+    if add_utc_tz:
+        localize_cols = {
+            col for col in columns if col in data.select_dtypes("datetime")
+        }
+        for col in localize_cols:
+            converted_data[col] = converted_data[col].dt.tz_localize(
+                "UTC", ambiguous="infer", nonexistent="shift_forward"
+            )
+    return converted_data
