@@ -127,7 +127,7 @@ class QuerySource:
         Parameters
         ----------
         key : str
-            The hiearchical path to the property (e.g. `source.description`)
+            The hierarchical path to the property (e.g. `source.description`)
 
         """
         path_elems = key.split(".")
@@ -474,7 +474,7 @@ class QuerySource:
         """
         req_source_items = {"args"}
         # match items surrounded by single {} but not double
-        param_pattern = r"(?!{{){([^}]+)}(?!})"
+        param_pattern = r"{(?<!{{)(?!{)([^}]+)}(?!})(?<!}})"
 
         valid_failures = []
 
