@@ -38,24 +38,32 @@ from .submission_mail import SubmissionMail
 from .threat_intelligence import Threatintelligence
 from .unknown_entity import UnknownEntity
 from .url import Url
+from .cloud_logon_session import CloudLogonSession
+from ..soc.incident import Incident
 
 # Dictionary to map text names of types to the class.
 Entity.ENTITY_NAME_MAP.update(
     {
         "account": Account,
         "azureresource": AzureResource,
+        "azure-resource": AzureResource,
         "host": Host,
         "process": Process,
         "file": File,
         "cloudapplication": CloudApplication,
+        "cloud-application": CloudApplication,
+        "dns": Dns,
         "dnsresolve": Dns,
         "ipaddress": IpAddress,
         "iotdevice": IoTDevice,
         "ip": IpAddress,
         "networkconnection": NetworkConnection,
+        "network-connection": NetworkConnection,
         "mailbox": Mailbox,
         "mail-message": MailMessage,
+        "mailmessage": MailMessage,
         "mail-cluster": MailCluster,
+        "mailcluster": MailCluster,
         "malware": Malware,
         "registry-key": RegistryKey,
         "registrykey": RegistryKey,
@@ -73,6 +81,9 @@ Entity.ENTITY_NAME_MAP.update(
         "url": Url,
         "unknown": UnknownEntity,
         "geolocation": GeoLocation,
+        "location": GeoLocation,
+        "incident": Incident,
+        "cloud-logon-session": CloudLogonSession,
     }
 )
 
@@ -83,7 +94,7 @@ def find_entity(entity):
     entity_classes = {
         cls.__name__.casefold(): cls for cls in Entity.ENTITY_NAME_MAP.values()
     }
-    if entity_cf in Entity.ENTITY_NAME_MAP.keys():
+    if entity_cf in Entity.ENTITY_NAME_MAP:
         print(f"Match found '{Entity.ENTITY_NAME_MAP[entity].__name__}'")
         return Entity.ENTITY_NAME_MAP[entity]
     if entity_cf in entity_classes:
