@@ -7,6 +7,7 @@
 import json
 import pprint
 import typing
+from datetime import datetime
 from abc import ABC
 from copy import deepcopy
 from typing import Any, Dict, List, Mapping, Optional, Type, Union
@@ -82,9 +83,10 @@ class Entity(ABC, Node):
 
         """
         super().__init__()
+        self.TimeGenerated = datetime.utcnow()
         self.Type = self._get_entity_type_name(type(self))
         # If we have an unknown entity see if we a type passed in
-        if self.Type == "unknownentity" and "Type" in kwargs:
+        if self.Type == "unknown" and "Type" in kwargs:
             self.Type = kwargs["Type"]
         # Make sure Type is in the class schema dictionary
         self._entity_schema["Type"] = None
@@ -99,6 +101,8 @@ class Entity(ABC, Node):
             # add AdditionalData dictionary if it's populated
             if "AdditionalData" in src_entity:
                 self.AdditionalData = src_entity["AdditionalData"]
+            if "TimeGenerated" in src_entity:
+                self.TimeGenerated = src_entity["TimeGenerated"]
 
         if kwargs:
             self.__dict__.update(kwargs)
@@ -212,7 +216,8 @@ class Entity(ABC, Node):
 
     def __getattr__(self, name: str):
         """Return the value of the named property 'name'."""
-        if name in self._entity_schema:
+        props = ["name_str", "description_str"]
+        if name in self._entity_schema or name in props:
             return None
         raise AttributeError(f"{name} is not a valid attribute.")
 
@@ -233,6 +238,8 @@ class Entity(ABC, Node):
         params = ", ".join(
             f"{name}={val}" for name, val in self.properties.items() if val
         )
+        if self.edges:
+            params = f"{params}, edges={'. '.join(str(edge) for edge in self.edges)}"
 
         if len(params) > 80:
             params = params[:80] + "..."
@@ -302,9 +309,7 @@ class Entity(ABC, Node):
         """Return the hash of the entity based on non-empty property values."""
         return hash(
             " ".join(
-                f"{prop}:{str(val)}"
-                for prop, val in self.properties.items()
-                if str(val)
+                f"{prop}:{val}" for prop, val in self.properties.items() if str(val)
             )
         )
 
@@ -336,10 +341,10 @@ class Entity(ABC, Node):
         if not isinstance(other, Entity):
             return False
         return not any(
-            self.properties[prop] != other.properties[prop]
-            and self.properties[prop]
-            and other.properties[prop]
-            for prop in self.properties
+            self.__dict__[prop] != other.__dict__[prop]
+            and self.__dict__[prop]
+            and other.__dict__[prop]
+            for prop in self.__dict__  # pylint: disable=consider-using-dict-items
         )
 
     def merge(self, other: Any) -> "Entity":
@@ -365,9 +370,11 @@ class Entity(ABC, Node):
         for prop, value in other.properties.items():
             if not value:
                 continue
-            if not self.properties[prop]:
+            if not self.__dict__[prop]:
                 setattr(merged, prop, value)
             # Future (ianhelle) - cannot merge ID field
+        if other.edges:
+            self.edges.update(other.edges)
         return merged
 
     def can_merge(self, other: Any) -> bool:
@@ -418,7 +425,7 @@ class Entity(ABC, Node):
         return {
             name: value
             for name, value in self.__dict__.items()
-            if not name.startswith("_")
+            if not name.startswith("_") and name != "edges" and value
         }
 
     @property
@@ -436,6 +443,21 @@ class Entity(ABC, Node):
         """
         return self.Type
 
+    @property
+    def name_str(self) -> str:
+        """
+        Return Name Description.
+
+        Returns
+        -------
+        str
+            Entity Name (optional). If not overridden
+            by the Entity instance type, it will return the
+            class name string.
+
+        """
+        return self.__class__.__name__
+
     @classmethod
     def instantiate_entity(
         cls, raw_entity: Mapping[str, Any], entity_type: Optional[Type] = None
@@ -461,15 +483,16 @@ class Entity(ABC, Node):
             return raw_entity
 
         entity_type_name = raw_entity.get("Type")
+
         if not entity_type_name and entity_type:
             entity_type_name = cls._get_entity_type_name(entity_type)
 
         if entity_type:
             return entity_type(raw_entity)
-        if entity_type_name in cls.ENTITY_NAME_MAP:
-            return cls.ENTITY_NAME_MAP[entity_type_name](raw_entity)
+        if entity_type_name and entity_type_name.lower() in cls.ENTITY_NAME_MAP:
+            return cls.ENTITY_NAME_MAP[entity_type_name.lower()](raw_entity)
 
-        raise TypeError("Could not find a suitable type for {}".format(entity_type))
+        raise TypeError(f"Could not find a suitable type for {entity_type}")
 
     @classmethod
     def _get_entity_type_name(cls, entity_type: Type) -> str:
@@ -487,12 +510,19 @@ class Entity(ABC, Node):
             The V3 serialized name.
 
         """
-        name = next(
-            iter(
-                (key for key, val in cls.ENTITY_NAME_MAP.items() if val == entity_type)
+        try:
+            name = next(
+                iter(
+                    (
+                        key
+                        for key, val in cls.ENTITY_NAME_MAP.items()
+                        if val == entity_type
+                    )
+                )
             )
-        )
-        return name or "unknown"
+        except StopIteration:
+            name = "unknown"
+        return name
 
     @property
     def node_properties(self) -> Dict[str, Any]:
@@ -505,11 +535,14 @@ class Entity(ABC, Node):
             Dictionary of name, value properties.
 
         """
-        return {
-            name: value
+        props = {
+            name: str(value)
             for name, value in self.properties.items()
             if not isinstance(value, (Entity, list)) and name != "edges"
         }
+        props["Description"] = self.description_str
+        props["Name"] = self.name_str
+        return props
 
     def to_networkx(self, graph: nx.Graph = None) -> nx.Graph:
         """
@@ -529,13 +562,16 @@ class Entity(ABC, Node):
 
         """
         graph = graph or nx.Graph()
-
         if not graph.has_node(self):
-            graph.add_node(self, **self.node_properties)
+            graph.add_node(self.name_str, **self.node_properties)
         for edge in self.edges:
-            if graph.has_edge(edge.source, edge.target):
+            if not isinstance(edge.source, Entity) or not isinstance(
+                edge.target, Entity
+            ):
                 continue
-            graph.add_edge(edge.source, edge.target, **edge.attrs)
+            if graph.has_edge(edge.source.name_str, edge.target.name_str):
+                continue
+            graph.add_edge(edge.source.name_str, edge.target.name_str, **edge.attrs)
 
             for node in (edge.source, edge.target):
                 # If this node has edges that are not in our graph
@@ -543,7 +579,9 @@ class Entity(ABC, Node):
                 if any(
                     edge
                     for edge in node.edges
-                    if not graph.has_edge(edge.source, edge.target)
+                    if isinstance(edge.source, Entity)
+                    and isinstance(edge.target, Entity)
+                    and not graph.has_edge(edge.source.name_str, edge.target.name_str)
                 ):
                     ent_node = typing.cast(Entity, node)
                     ent_node.to_networkx(graph)
@@ -607,9 +645,9 @@ class Entity(ABC, Node):
 
         """
         func_path = func_name.split(".") if "." in func_name else [func_name]
-        curr_attr = cls
+        curr_attr: Optional[Any] = cls
         for path in func_path:
-            curr_attr = getattr(curr_attr, path, None)
+            curr_attr = getattr(curr_attr, path, None)  # type: ignore
             if not curr_attr:
                 raise AttributeError(f"No function found for {func_name}")
         if not hasattr(curr_attr, "pivot_properties"):
@@ -661,3 +699,8 @@ class Entity(ABC, Node):
                 "This is not a pivot function.",
             )
         delattr(cls, func_name)
+
+
+def camelcase_property_names(input_ent: Dict[str, Any]) -> Dict[str, Any]:
+    """Change initial letter Microsoft Sentinel API entity properties to upper case."""
+    return {key[0].upper() + key[1:]: input_ent[key] for key in input_ent}
