@@ -8,7 +8,6 @@ from datetime import datetime
 from typing import Any, Callable, Dict, Iterable, Optional, Type
 
 import pkg_resources
-from IPython import get_ipython
 
 from .._version import VERSION
 from ..common.timespan import TimeSpan
@@ -22,7 +21,7 @@ from .pivot_browser import PivotBrowser
 from .pivot_data_queries import add_data_queries_to_entities
 from .pivot_register import PivotRegistration
 from .pivot_register_reader import add_unbound_pivot_function, register_pivots
-from .pivot_ti_provider import add_ioc_queries_to_entities
+from .pivot_ti_provider import add_ioc_queries_to_entities, register_ti_pivot_providers
 from . import entities
 
 __version__ = VERSION
@@ -31,11 +30,6 @@ __author__ = "Ian Hellen"
 _DEF_PIVOT_REG_FILE = "resources/mp_pivot_reg.yaml"
 
 
-# Import IPython magic if in an IPython environment
-if get_ipython():
-    from . import txt_df_magic  # noqa: F401
-
-
 class Pivot:
     """Pivot environment loader."""
 
@@ -116,6 +110,9 @@ class Pivot:
         # load TI functions
         add_ioc_queries_to_entities(self.get_provider("TILookup"), container="ti")
 
+        # Add pivots from Pivot-capable TI providers
+        register_ti_pivot_providers(self.get_provider("TILookup"), self)
+
         # Add pivots from config registry
         register_pivots(
             file_path=self._get_def_pivot_reg(), container="util", namespace=namespace
