@@ -41,6 +41,7 @@ from ..common.utility import (
     unit_testing,
 )
 from ..config import MpConfigFile
+from ..datamodel.pivot import Pivot
 from .azure_ml_tools import check_versions as check_versions_aml
 from .azure_ml_tools import is_in_aml
 from .user_config import load_user_defaults
@@ -106,7 +107,7 @@ Some functionality (such as Threat Intel lookups) will not function without
 valid configuration settings.<br>
 The following resources will help you set up your configuration:
 <ul>{"".join(_HELP_URIS)}</ul>
-<br>You can load and run the first two of these from the Azure Sentinel
+<br>You can load and run the first two of these from the Microsoft Sentinel
 <b>Notebooks</b> tab
 """
 
@@ -114,20 +115,20 @@ The following resources will help you set up your configuration:
 _PANDAS_REQ_VERSION = (0, 25, 0)
 
 
-def _get_verbose_setting() -> Callable[[Optional[bool]], bool]:
+def _get_verbosity_setting() -> Callable[[Optional[int]], int]:
     """Closure for holding trace setting."""
-    _verbose_enabled = False
+    _verbosity = 1
 
-    def _verbose(verbose: Optional[bool] = None) -> bool:
-        nonlocal _verbose_enabled
-        if verbose is not None:
-            _verbose_enabled = verbose
-        return _verbose_enabled
+    def _verbose(verbosity: Optional[int] = None) -> int:
+        nonlocal _verbosity
+        if verbosity is not None:
+            _verbosity = verbosity
+        return _verbosity
 
     return _verbose
 
 
-_VERBOSE = _get_verbose_setting()
+_VERBOSITY: Callable[[Optional[int]], int] = _get_verbosity_setting()
 
 _NB_IMPORTS = [
     dict(pkg="pandas", alias="pd"),
@@ -139,9 +140,11 @@ _NB_IMPORTS = [
     dict(pkg="pathlib", tgt="Path"),
     dict(pkg="matplotlib.pyplot", alias="plt"),
     dict(pkg="matplotlib", tgt="MatplotlibDeprecationWarning"),
-    dict(pkg="seaborn", alias="sns"),
     dict(pkg="numpy", alias="np"),
 ]
+if sns is not None:
+    _NB_IMPORTS.append(dict(pkg="seaborn", alias="sns"))
+
 _MP_IMPORTS = [
     dict(pkg="msticpy"),
     dict(pkg="msticpy.data", tgt="QueryProvider"),
@@ -151,6 +154,7 @@ _MP_IMPORTS = [
     dict(pkg="msticpy.common.wsconfig", tgt="WorkspaceConfig"),
     dict(pkg="msticpy.datamodel.pivot", tgt="Pivot"),
     dict(pkg="msticpy.datamodel", tgt="entities"),
+    dict(pkg="msticpy.nbtools", tgt="nbmagics"),
     dict(pkg="msticpy.vis", tgt="mp_pandas_plot"),
 ]
 _MP_IMPORT_ALL = [
@@ -182,7 +186,17 @@ current_providers: Dict[str, Any] = {}  # pylint: disable=invalid-name
 
 
 def _pr_output(*args):
-    """Send output to IPython display or print."""
+    """Output to IPython display or print."""
+    if not _VERBOSITY():
+        return
+    if is_ipython():
+        display(HTML(" ".join([*args, "<br>"]).replace("\n", "<br>")))
+    else:
+        print(*args)
+
+
+def _err_output(*args):
+    """Output to IPython display or print - always output regardless of verbosity."""
     if is_ipython():
         display(HTML(" ".join([*args, "<br>"]).replace("\n", "<br>")))
     else:
@@ -239,10 +253,15 @@ def init_notebook(
         exception hander. Any exceptions derived from MsticpyUserException
         are displayed but do not produce a stack trace, etc.
         Defaults to system/user settings if no value is supplied.
-    verbose : bool, optional
-        Display more verbose status, by default False
+    verbose : Union[int, bool], optional
+        Controls amount if status output, by default 1
+        0 = No output
+        1 or False = Brief output (default)
+        2 or True = Detailed output
     no_config_check : bool, optional
         Skip the check for valid configuration. Default is False.
+    verbosity : int, optional
+
 
     Returns
     -------
@@ -260,17 +279,22 @@ def init_notebook(
     global current_providers  # pylint: disable=global-statement, invalid-name
 
     check_kwargs(
-        kwargs, ["user_install", "friendly_exceptions", "no_config_check", "verbose"]
+        kwargs,
+        [
+            "user_install",
+            "friendly_exceptions",
+            "no_config_check",
+            "verbosity",
+            "verbose",
+        ],
     )
     user_install: bool = kwargs.pop("user_install", False)
     friendly_exceptions: Optional[bool] = kwargs.pop("friendly_exceptions", None)
     no_config_check: bool = kwargs.pop("no_config_check", False)
 
-    verbose: bool = kwargs.pop("verbose", False)
+    _set_verbosity(**kwargs)
 
-    _VERBOSE(verbose)
-
-    display(HTML("<hr><h4>Starting Notebook initialization...</h4>"))
+    _pr_output("<hr><h4>Starting Notebook initialization...</h4>")
     # Check Azure ML environment
     if is_in_aml():
         check_versions_aml(*_get_aml_globals(namespace))
@@ -303,12 +327,18 @@ def init_notebook(
     if friendly_exceptions is None:
         friendly_exceptions = get_config("msticpy.FriendlyExceptions")
     if friendly_exceptions:
-        if verbose:
+        if _VERBOSITY() == 2:  # type: ignore
             _pr_output("Friendly exceptions enabled.")
         InteractiveShell.showtraceback = _hook_ipython_exceptions(
             InteractiveShell.showtraceback
         )
 
+    # load pivots
+    stdout_cap = io.StringIO()
+    with redirect_stdout(stdout_cap):
+        _load_pivots(namespace=namespace)
+        _pr_output(stdout_cap.getvalue())
+
     # User defaults
     stdout_cap = io.StringIO()
     with redirect_stdout(stdout_cap):
@@ -322,7 +352,7 @@ def init_notebook(
 
     # show any warnings
     init_status = _show_init_warnings(imp_ok, conf_ok)
-    display(HTML("<h4>Notebook initialization complete</h4>"))
+    _pr_output("<h4>Notebook initialization complete</h4>")
     return init_status
 
 
@@ -343,6 +373,17 @@ def _show_init_warnings(imp_ok, conf_ok):
     return False
 
 
+def _set_verbosity(**kwargs):
+    """Set verbosity of output from boolean or int `verbose` param."""
+    verbosity = 1
+    verb_param = kwargs.pop("verbose", kwargs.pop("verbosity", 1))
+    if isinstance(verb_param, bool):
+        verbosity = 2 if verb_param else 1
+    elif isinstance(verb_param, int):
+        verbosity = min(2, max(0, verb_param))
+    _VERBOSITY(verbosity)
+
+
 def list_default_imports():
     """List the default imports for `init_notebook`."""
     for imp_group in (_NB_IMPORTS, _MP_IMPORTS):
@@ -388,7 +429,7 @@ def _get_aml_globals(namespace: Dict[str, Any]):
     return py_ver, mp_ver, extras
 
 
-def _global_imports(  # noqa: MC0001
+def _global_imports(
     namespace: Dict[str, Any],
     additional_packages: List[str] = None,
     user_install: bool = False,
@@ -396,30 +437,24 @@ def _global_imports(  # noqa: MC0001
     def_imports: str = "all",
 ):
     import_list = []
-    try:
-        if def_imports.casefold() in ["all", "nb"]:
-            for imp_pkg in _NB_IMPORTS:
-                if sns is None and imp_pkg.get("pkg") == "seaborn":
-                    continue
-                _imp_from_package(nm_spc=namespace, **imp_pkg)
-                import_list.append(_extract_pkg_name(imp_pkg))
-            _check_and_reload_pkg(namespace, pd, _PANDAS_REQ_VERSION, "pd")
+    imports, imports_all = _build_import_list(def_imports)
 
-        if def_imports.casefold() in ["all", "msticpy"]:
-            for imp_pkg in _MP_IMPORTS:
-                _imp_from_package(nm_spc=namespace, **imp_pkg)
-                import_list.append(_extract_pkg_name(imp_pkg))
-            for imp_pkg in _MP_IMPORT_ALL:
-                _imp_module_all(nm_spc=namespace, **imp_pkg)
-                import_list.append(_extract_pkg_name(imp_pkg))
+    try:
+        for imp_pkg in imports:
+            _imp_from_package(nm_spc=namespace, **imp_pkg)
+            import_list.append(_extract_pkg_name(imp_pkg))
+        for imp_pkg in imports_all:
+            _imp_module_all(nm_spc=namespace, **imp_pkg)
+            import_list.append(_extract_pkg_name(imp_pkg))
+        _check_and_reload_pkg(namespace, pd, _PANDAS_REQ_VERSION, "pd")
 
         if additional_packages:
             pkg_success = check_and_install_missing_packages(
                 additional_packages, user=user_install
             )
             if not pkg_success:
-                _pr_output("One or more packages failed to install.")
-                _pr_output(
+                _err_output("One or more packages failed to install.")
+                _err_output(
                     "Please re-run init_notebook() with the parameter user_install=True."
                 )
             # We want to force import lib to see anything that we've
@@ -430,14 +465,26 @@ def _global_imports(  # noqa: MC0001
                 _import_extras(nm_spc=namespace, extra_imports=extra_imports)
             )
 
-        if import_list:
-            _pr_output("Imported:", ", ".join(imp for imp in import_list if imp))
+        _pr_output("Imported:", ", ".join(imp for imp in import_list if imp))
         return True
     except ImportError as imp_err:
         display(HTML(_IMPORT_ERR_MSSG.format(err=imp_err)))
         return False
 
 
+def _build_import_list(
+    def_imports: str,
+) -> Tuple[List[Dict[str, str]], List[Dict[str, str]]]:
+    imports = []
+    imports_all = []
+    if def_imports.casefold() in ["all", "nb"]:
+        imports.extend(_NB_IMPORTS)
+    if def_imports.casefold() in ["all", "msticpy"]:
+        imports.extend(_MP_IMPORTS)
+        imports_all.extend(_MP_IMPORT_ALL)
+    return imports, imports_all
+
+
 _AZ_SENT_ERRS = [
     "Missing or empty 'AzureSentinel' section",
     "Missing or empty 'Workspaces' key in 'AzureSentinel' section",
@@ -445,7 +492,7 @@ _AZ_SENT_ERRS = [
 
 
 def _verify_no_azs_errors(errs):
-    """Verify none of the Azure Sentinel errors appear in `errs`."""
+    """Verify none of the Microsoft Sentinel errors appear in `errs`."""
     return all(az_err not in errs for az_err in _AZ_SENT_ERRS)
 
 
@@ -457,14 +504,15 @@ def _get_or_create_config() -> bool:
     # 4. if file and check_file_contents -> return ok
     # 5. search_for_file(config.json)
     # 6. If config.json -> import into mpconfig and save
-    # 7. Error - no Azure sentinel config
+    # 7. Error - no Microsoft Sentinel config
     mp_path = os.environ.get("MSTICPYCONFIG")
     if mp_path and not Path(mp_path).is_file():
-        display(HTML(_MISSING_MPCONFIG_ENV_ERR))
+        _err_output(_MISSING_MPCONFIG_ENV_ERR)
     if not mp_path or not Path(mp_path).is_file():
         mp_path = search_for_file("msticpyconfig.yaml", paths=[".", ".."])
 
     if mp_path:
+        errs: List[str] = []
         try:
             std_out_cap = io.StringIO()
             with redirect_stdout(std_out_cap):
@@ -472,7 +520,7 @@ def _get_or_create_config() -> bool:
             if errs:
                 _pr_output(std_out_cap.getvalue())
             if _verify_no_azs_errors(errs):
-                # If the mpconfig has an Azure Sentinel config, return here
+                # If the mpconfig has a Microsoft Sentinel config, return here
                 return True
         # pylint: disable=broad-except
         except Exception as err:
@@ -489,7 +537,7 @@ def _get_or_create_config() -> bool:
         _populate_config_to_mp_config(mp_path, config_json)
         return True
 
-    _pr_output("No valid configuration for Azure Sentinel found.")
+    _pr_output("No valid configuration for Microsoft Sentinel found.")
     return False
 
 
@@ -505,16 +553,16 @@ def _populate_config_to_mp_config(mp_path, config_json):
         mp_config_convert.settings["AzureSentinel"]["Workspaces"][
             "Default"
         ] = def_azs_settings.copy()
-    mssg = f"Created '{mp_path}'' with Azure Sentinel settings."
+    mssg = f"Created '{mp_path}'' with Microsoft Sentinel settings."
     if Path(mp_path).exists():
         # If there is an existing file read it in
-        mp_config_text = Path(mp_path).read_text()
+        mp_config_text = Path(mp_path).read_text(encoding="utf-8")
         mp_config_settings = yaml.safe_load(mp_config_text)
         # update exist settings with the AzSent settings from config.json
         mp_config_settings.update(mp_config_convert.settings)
         # update MpConfigFile with the merged settings
         mp_config_convert.settings = mp_config_settings
-        mssg = f"Updated '{mp_path}'' with Azure Sentinel settings."
+        mssg = f"Updated '{mp_path}'' with Microsoft Sentinel settings."
     # Save the file
     mp_config_convert.save_to_file(mp_path, backup=True)
     _pr_output(mssg)
@@ -544,6 +592,28 @@ def _set_nb_options(namespace):
         os.environ["KQLMAGIC_CONFIGURATION"] = kql_config
 
 
+def _load_pivots(namespace):
+    """Load pivot functions."""
+    if not Pivot.current:
+        pivot = Pivot()
+        namespace["pivot"] = pivot
+
+    vt_pivot = None
+    try:
+        get_config("TIProviders.VirusTotal")
+        try:
+            vt_pivot = importlib.import_module("msticpy.sectools.vtlookupv3.vt_pivot")
+            namespace["vt_pivot"] = vt_pivot
+        except ImportError:
+            # Importing Vt3 libraries failed.
+            pass
+    except KeyError:
+        # No VT settings detected
+        pass
+    if vt_pivot:
+        vt_pivot.add_pivot_functions()
+
+
 def _import_extras(nm_spc: Dict[str, Any], extra_imports: List[str]):
     added_imports = []
     if isinstance(extra_imports, str):
@@ -569,13 +639,13 @@ def _imp_module(nm_spc: Dict[str, Any], module_name: str, alias: str = None):
     try:
         mod = importlib.import_module(module_name)
     except ImportError:
-        display(HTML(_IMPORT_MODULE_MSSG.format(module=module_name)))
+        _err_output(_IMPORT_MODULE_MSSG.format(module=module_name))
         return None
     if alias:
         nm_spc[alias] = mod
     else:
         nm_spc[module_name] = mod
-    if _VERBOSE():  # type: ignore
+    if _VERBOSITY() == 2:  # type: ignore
         _pr_output(f"{module_name} imported (alias={alias})")
     return mod
 
@@ -585,13 +655,13 @@ def _imp_module_all(nm_spc: Dict[str, Any], module_name):
     try:
         imported_mod = importlib.import_module(module_name)
     except ImportError:
-        display(HTML(_IMPORT_MODULE_MSSG.format(module=module_name)))
+        _err_output(_IMPORT_MODULE_MSSG.format(module=module_name))
         return
     for item in dir(imported_mod):
         if item.startswith("_"):
             continue
         nm_spc[item] = getattr(imported_mod, item)
-    if _VERBOSE():  # type: ignore
+    if _VERBOSITY() == 2:  # type: ignore
         _pr_output(f"All items imported from {module_name}")
 
 
@@ -609,14 +679,14 @@ def _imp_from_package(
         try:
             mod = importlib.import_module(pkg)
         except ImportError:
-            display(HTML(_IMPORT_MODULE_MSSG.format(module=pkg)))
+            _err_output(_IMPORT_MODULE_MSSG.format(module=pkg))
             return None
         obj = getattr(mod, tgt)
     if alias:
         nm_spc[alias] = obj
     else:
         nm_spc[tgt] = obj
-    if _VERBOSE():  # type: ignore
+    if _VERBOSITY() == 2:  # type: ignore
         _pr_output(f"{tgt} imported from {pkg} (alias={alias})")
     return obj
 
@@ -631,7 +701,7 @@ def _check_and_reload_pkg(
         raise MsticpyException(f"Package {pkg_name} has no version data.")
     pkg_version = tuple(int(v) for v in pkg.__version__.split("."))
     if pkg_version < req_version:
-        display(HTML(_MISSING_PKG_WARN.format(package=pkg_name)))
+        _err_output(_MISSING_PKG_WARN.format(package=pkg_name))
         resp = (
             input("Install the package now? (y/n)") if not unit_testing() else "y"
         )  # nosec
@@ -645,7 +715,7 @@ def _check_and_reload_pkg(
                 importlib.reload(pkg)
             else:
                 _imp_module(nm_spc, pkg_name, alias=alias)
-    if _VERBOSE():  # type: ignore
+    if _VERBOSITY() == 2:  # type: ignore
         _pr_output(f"{pkg_name} imported version {pkg.__version__}")
     return warn_mssg
 
@@ -674,8 +744,7 @@ def _check_azure_cli_status():
             _pr_output(message)
         elif status == AzureCliStatus.CLI_NOT_INSTALLED:
             _pr_output(
-                "Azure CLI not detected. AzCLI single sign-on disabled"
-                " ({_CLI_WIKI_MSSG_SHORT})"
+                "Azure CLI credentials not detected." f" ({_CLI_WIKI_MSSG_SHORT})"
             )
         elif message:
             _pr_output("\n".join([message, _CLI_WIKI_MSSG_GEN]))
