@@ -7,45 +7,57 @@
 from collections import namedtuple
 from typing import Optional, Tuple, Union
 
-from bokeh.io import output_notebook, show, reset_output
-from bokeh.plotting import figure
-from bokeh.transform import dodge, factor_cmap, linear_cmap
-from bokeh.models import (
-    HoverTool,
-    ColumnDataSource,
-    CustomJS,
-    # Legend,
-    # LegendItem,
-    BoxSelectTool,
-    RangeTool,
-    ColorBar,
-)
-
-# pylint: disable=no-name-in-module
-from bokeh.palettes import viridis
+import numpy as np
+import pandas as pd
+from bokeh.io import output_notebook, reset_output, show
 
 # pylint: enable=no-name-in-module
 from bokeh.layouts import column, row
-from bokeh.models import LayoutDOM
-from bokeh.models.widgets import DataTable, TableColumn, DateFormatter
+from bokeh.models import (
+    BoxSelectTool,
+    ColorBar,
+    ColumnDataSource,
+    CustomJS,
+    HoverTool,
+    LayoutDOM,
+    RangeTool,
+)
+from bokeh.models.widgets import DataTable, DateFormatter, TableColumn
 
-import numpy as np
-import pandas as pd
+# pylint: disable=no-name-in-module
+from bokeh.palettes import viridis
+from bokeh.plotting import figure
+from bokeh.transform import dodge, factor_cmap, linear_cmap
 
-from ..sectools.process_tree_utils import (
-    build_process_tree,
-    ProcSchema,
-    infer_schema,
-    ProcessTreeSchemaException,
+from .._version import VERSION
+from ..common.utility import check_kwargs
+from ..sectools.proc_tree_builder import build_process_tree, infer_schema
+from ..sectools.proc_tree_schema import ProcessTreeSchemaException, ProcSchema
+from ..sectools.proc_tree_schema import ColNames as Col
+
+# pylint: disable=unused-import
+from ..sectools.process_tree_utils import (  # noqa F401
+    get_ancestors,
+    get_children,
+    get_descendents,
+    get_parent,
+    get_process,
+    get_process_key,
+    get_root,
+    get_root_tree,
+    get_roots,
+    get_siblings,
+    get_summary_info,
+    get_tree_depth,
 )
 
-from ..common.utility import check_kwargs
-from .._version import VERSION
+# pylint: enable=unused-import
+
 
 __version__ = VERSION
 __author__ = "Ian Hellen"
 
-_DEFAULT_KWARGS = ["height", "title", "width"]
+_DEFAULT_KWARGS = ["height", "title", "width", "hide_legend", "pid_fmt"]
 
 
 def build_and_show_process_tree(
@@ -73,12 +85,32 @@ def build_and_show_process_tree(
     kwargs : Dict[str, Any]
         Additional arguments passed to plot_process_tree
 
+    Other Parameters
+    ----------------
+    height : int, optional
+        The height of the plot figure
+        (the default is 700)
+    width : int, optional
+        The width of the plot figure (the default is 900)
+    title : str, optional
+        Title to display (the default is None)
+    hide_legend : bool, optional
+        Hide the legend box, even if legend_col is specified.
+    pid_fmt : str, optional
+        Display Process ID as 'dec' (decimal) or 'hex' (hexadecimal),
+        default is 'hex'.
+
     Returns
     -------
     Tuple[figure, LayoutDOM]:
         figure - The main bokeh.plotting.figure
         Layout - Bokeh layout structure.
 
+    Notes
+    -----
+    For full parameter set for process tree display see the
+    help for plot_process_tree.
+
     See Also
     --------
     plot_process_tree
@@ -94,8 +126,8 @@ def build_and_show_process_tree(
     )
 
 
-# pylint: disable=too-many-locals
-def plot_process_tree(
+# pylint: disable=too-many-locals, too-many-statements
+def plot_process_tree(  # noqa: MC0001
     data: pd.DataFrame,
     schema: ProcSchema = None,
     output_var: str = None,
@@ -130,6 +162,11 @@ def plot_process_tree(
         The width of the plot figure (the default is 900)
     title : str, optional
         Title to display (the default is None)
+    hide_legend : bool, optional
+        Hide the legend box, even if legend_col is specified.
+    pid_fmt : str, optional
+        Display Process ID as 'dec' (decimal) or 'hex' (hexadecimal),
+        default is 'hex'.
 
     Returns
     -------
@@ -152,19 +189,22 @@ def plot_process_tree(
     reset_output()
     output_notebook()
 
-    data, schema, levels, n_rows = _pre_process_tree(data, schema)
-    if schema is None:
-        raise ProcessTreeSchemaException("Could not infer schema from data set.")
+    plot_height: int = kwargs.pop("height", 700)
+    plot_width: int = kwargs.pop("width", 900)
+    title: str = kwargs.pop("title", "ProcessTree")
+    hide_legend = kwargs.pop("hide_legend", False)
+    pid_fmt = kwargs.pop("pid_fmt", "hex")
 
-    source = ColumnDataSource(data=data)
+    proc_data, schema, levels, n_rows = _pre_process_tree(data, schema, pid_fmt=pid_fmt)
+    if schema is None:
+        raise ProcessTreeSchemaException("Could not infer data schema from data set.")
+
+    source = ColumnDataSource(data=proc_data)
     # Get legend/color bar map
     fill_map, color_bar = _create_fill_map(source, legend_col)
 
     max_level = max(levels) + 3
     min_level = min(levels)
-    plot_height: int = kwargs.pop("height", 700)
-    plot_width: int = kwargs.pop("width", 900)
-    title: str = kwargs.pop("title", "ProcessTree")
 
     if color_bar:
         title += " (color bar = {legend_col})"
@@ -176,12 +216,14 @@ def plot_process_tree(
         plot_height=plot_height,
         x_range=(min_level, max_level),
         y_range=y_start_range,
-        tools=["ypan", "reset", "save", "tap"],
+        tools=["reset", "save", "tap", "ywheel_pan"],
         toolbar_location="above",
+        active_scroll="ywheel_pan",
     )
 
     hover = HoverTool(
-        tooltips=_get_tool_tips(schema), formatters={"TimeGenerated": "datetime"}
+        tooltips=_get_tool_tips(schema),
+        formatters={f"@{schema.time_stamp}": "datetime"},
     )
     b_plot.add_tools(hover)
 
@@ -198,6 +240,9 @@ def plot_process_tree(
     rect_plot = b_plot.rect(x=rect_x, y="Row", **rect_plot_params)
     if legend_col and not color_bar:
         b_plot.legend.title = legend_col
+        b_plot.legend.label_text_font_size = "7pt"
+    if hide_legend:
+        b_plot.legend.visible = False
 
     text_props = {"source": source, "text_align": "left", "text_baseline": "middle"}
 
@@ -208,13 +253,25 @@ def plot_process_tree(
         return dodge("Row", y_offset, range=b_plot.y_range)
 
     b_plot.text(
-        x=x_dodge(0.1), y=y_dodge(-0.2), text="cmd", text_font_size="7pt", **text_props
+        x=x_dodge(0.1),
+        y=y_dodge(-0.2),
+        text="__cmd_line$$",
+        text_font_size="7pt",
+        **text_props,
     )
     b_plot.text(
-        x=x_dodge(0.1), y=y_dodge(0.25), text="Exe", text_font_size="8pt", **text_props
+        x=x_dodge(0.1),
+        y=y_dodge(0.25),
+        text="__proc_name$$",
+        text_font_size="8pt",
+        **text_props,
     )
     b_plot.text(
-        x=x_dodge(1.8), y=y_dodge(0.25), text="PID", text_font_size="8pt", **text_props
+        x=x_dodge(2.2),
+        y=y_dodge(0.25),
+        text="__proc_id$$",
+        text_font_size="8pt",
+        **text_props,
     )
 
     # Plot options
@@ -249,19 +306,29 @@ def plot_process_tree(
     return b_plot, plot_elems
 
 
-# pylint: enable=too-many-locals
+# pylint: enable=too-many-locals, too-many-statements
 
 
 TreeResult = namedtuple("TreeResult", "proc_tree, schema, levels, n_rows")
 
 
-def _pre_process_tree(proc_tree: pd.DataFrame, schema: ProcSchema = None):
+def _pre_process_tree(
+    proc_tree: pd.DataFrame, schema: ProcSchema = None, pid_fmt: str = "hex"
+):
     """Extract dimensions and formatted values from proc_tree."""
+    # Check if this table already seems to have the proc_tree metadata
+    missing_cols = _check_proc_tree_schema(proc_tree)
+    if missing_cols:
+        proc_tree = build_process_tree(procs=proc_tree, schema=schema)
+
     if schema is None:
         schema = infer_schema(proc_tree)
+    if schema is None:
+        return TreeResult(None, None, None, None)
+
     _validate_plot_schema(proc_tree, schema)
 
-    proc_tree = proc_tree.sort_values("path", ascending="True").reset_index()
+    proc_tree = proc_tree.sort_values("path", ascending=True).reset_index()
     n_rows = len(proc_tree)
     proc_tree["Row"] = proc_tree.index
     proc_tree["Row"] = n_rows - proc_tree["Row"]
@@ -269,26 +336,37 @@ def _pre_process_tree(proc_tree: pd.DataFrame, schema: ProcSchema = None):
 
     levels = proc_tree["Level"].unique()
 
-    max_cmd_len = int(350 / len(levels))
-    long_cmd = proc_tree[schema.cmd_line].str.len() > max_cmd_len
-    proc_tree.loc[long_cmd, "cmd"] = (
-        proc_tree[schema.cmd_line].str[:max_cmd_len] + "..."
-    )
-    proc_tree.loc[~long_cmd, "cmd"] = proc_tree[schema.cmd_line].fillna(
-        "cmdline unknown"
-    )
-    proc_tree["Exe"] = proc_tree.apply(
+    proc_tree[schema.process_name] = proc_tree[schema.process_name].fillna("unknown")
+    proc_tree["__proc_name$$"] = proc_tree.apply(
         lambda x: x[schema.process_name].split(schema.path_separator)[-1], axis=1
     )
-    pid_fmt = (
-        lambda x: f"PID: {x} ({int(x, base=16)})"
-        if str(x).startswith("0x")
-        else f"PID: 0x{int(x):x} ({int(x)})"
+    proc_tree[schema.process_id] = proc_tree[schema.process_id].fillna("unknown")
+    proc_tree["__proc_id$$"] = proc_tree[schema.process_id].apply(
+        _pid_fmt, args=(pid_fmt,)
     )
-    proc_tree["PID"] = proc_tree[schema.process_id].apply(pid_fmt)
+
+    # trim long commandlines
+    max_cmd_len = 500 // len(levels)
+    proc_tree[schema.cmd_line] = proc_tree[schema.cmd_line].astype(str)
+    long_cmd = proc_tree[schema.cmd_line].str.len() > max_cmd_len
+    proc_tree.loc[long_cmd, "__cmd_line$$"] = (
+        proc_tree[long_cmd][schema.cmd_line].str[:max_cmd_len] + "..."
+    )
+    # replace missing cmdlines
+    proc_tree.loc[~long_cmd, "__cmd_line$$"] = proc_tree[~long_cmd][
+        schema.cmd_line
+    ].fillna("cmdline unknown")
     return TreeResult(proc_tree=proc_tree, schema=schema, levels=levels, n_rows=n_rows)
 
 
+def _pid_fmt(pid, pid_fmt):
+    if pid_fmt == "hex":
+        return f"PID: {pid}" if str(pid).startswith("0x") else f"PID: 0x{int(pid):x}"
+    return (
+        f"PID: {pid}" if not str(pid).startswith("0x") else f"PID: {int(pid, base=16)}"
+    )
+
+
 def _validate_plot_schema(proc_tree: pd.DataFrame, schema):
     """Validate that we have the required columns."""
     required_cols = set(
@@ -323,12 +401,12 @@ def _get_tool_tips(schema: ProcSchema):
     """Return tool tip formatter."""
     return [
         ("Process", f"@{schema.process_name}"),
-        ("PID", "@PID"),
+        ("PID", f"@{schema.process_id}"),
         ("CmdLine", f"@{schema.cmd_line}"),
         ("SubjUser", f"@{schema.user_name}"),
         ("SubjLgnId", f"@{schema.logon_id}"),
-        ("TargLgnId", f"@{schema.target_logon_id}"),
-        ("Time", f"@{schema.time_stamp}{{%F %T}}"),
+        ("TgtLgnId", f"@{schema.target_logon_id}"),
+        ("Time", f"@{schema.time_stamp}{{%F %T.%3N}}"),
     ]
 
 
@@ -341,16 +419,15 @@ def _create_js_callback(source: ColumnDataSource, result_var: str) -> CustomJS:
         for (var i = 0; i < inds.length; i++) {
             output.push(source.data[itemkey][inds[i]])
         }
-        out_str = JSON.stringify(output);
-        py_str = `${output_var} = ${out_str}`;
+        var out_str = JSON.stringify(output);
+        var py_str = `${output_var} = ${out_str}`;
         console.log(py_str);
         IPython.notebook.kernel.execute(py_str);
     """
-    get_selected = CustomJS(
-        args=dict(source=source, itemkey="proc_key", output_var=result_var),
+    return CustomJS(
+        args=dict(source=source, itemkey=Col.proc_key, output_var=result_var),
         code=ret_var_js,
     )
-    return get_selected
 
 
 def _create_fill_map(
@@ -457,31 +534,24 @@ def _create_data_table(
         if col in source.column_names
     ]
 
-    data_table = DataTable(
-        source=source, columns=columns + columns2, width=950, height=150
-    )
-    return data_table
+    return DataTable(source=source, columns=columns + columns2, width=950, height=150)
 
 
 def _check_proc_tree_schema(data):
     """Return true if expected process tree columns are present."""
-    input_cols = set(data.columns)
+    if data.index.name != Col.proc_key:
+        return {Col.proc_key}
     expected_cols = set(
         [
-            "new_process_lc",
-            "parent_proc_lc",
-            "source_index",
-            "new_process_lc_par",
-            "source_index_par",
-            "parent_key",
+            Col.parent_key,
             "IsRoot",
             "IsLeaf",
             "IsBranch",
             "path",
-            "parent_index",
+            # "parent_index",
         ]
     )
-    return expected_cols - input_cols
+    return expected_cols - set(data.columns)
 
 
 # pylint: disable=too-few-public-methods
@@ -519,6 +589,11 @@ class ProcessTreeAccessor:
             The width of the plot figure (the default is 900)
         title : str, optional
             Title to display (the default is None)
+        hide_legend : bool, optional
+            Hide the legend box, even if legend_col is specified.
+        pid_fmt : str, optional
+            Display Process ID as 'dec' (decimal) or 'hex' (hexadecimal),
+            default is 'hex'.
 
         Returns
         -------
@@ -540,9 +615,8 @@ class ProcessTreeAccessor:
         schema : ProcSchema, optional
             The column schema to use, by default None
             If None, then the schema is inferred
-        show_progress : bool
-            Shows the progress of the process (helpful for
-            very large data sets)
+        show_summary : bool
+            Shows summary of the built tree, default is False. : bool
         debug : bool
             If True produces extra debugging output,
             by default False
@@ -562,6 +636,6 @@ class ProcessTreeAccessor:
         return build_process_tree(
             procs=self._df,
             schema=schema,
-            show_progress=kwargs.get("show_progress", False),
+            show_summary=kwargs.get("show_summary", kwargs.get("show_progress", False)),
             debug=kwargs.get("debug", False),
         )
