@@ -9,6 +9,7 @@ from json import JSONDecodeError
 from typing import Dict, Any, List
 
 import pandas as pd
+from deprecated.sphinx import deprecated
 
 from .._version import VERSION
 from ..datamodel.entities import Entity, UnknownEntity
@@ -19,6 +20,7 @@ __version__ = VERSION
 __author__ = "Ian Hellen"
 
 
+@deprecated(reason="Replaced by Alert entity in datamodel", version="1.7.0")
 @export
 class SecurityAlert(SecurityBase):
     """
@@ -33,7 +35,7 @@ class SecurityAlert(SecurityBase):
         super().__init__(src_row=src_row)
 
         # add entities to dictionary to remove dups
-        self._src_entities: Dict[int, Entity] = dict()
+        self._src_entities: Dict[int, Entity] = {}
 
         self.extended_properties: Dict[str, Any] = {}
         if src_row is not None:
@@ -79,22 +81,20 @@ class SecurityAlert(SecurityBase):
     def to_html(self, show_entities=False) -> str:
         """Return the item as HTML string."""
         if self.properties:
-            title = """
+            start = self.properties.get(
+                "StartTimeUtc", self.properties.get("StartTime", "no timestamp")
+            )
+            name = self.properties.get(
+                "AlertDisplayName",
+                self.properties.get("DisplayName", "no alert name"),
+            )
+            entity = self.properties.get("CompromisedEntity", "unknown")
+            title = f"""
             <h3>Alert: '{name}'</h3>
             <b>Alert_time:</b> {start},
             <b>Compr_entity:</b> {entity},
-            <b>Alert_id:</b> {id}
-            """.format(
-                start=self.properties.get(
-                    "StartTimeUtc", self.properties.get("StartTime", "no timestamp")
-                ),
-                name=self.properties.get(
-                    "AlertDisplayName",
-                    self.properties.get("DisplayName", "no alert name"),
-                ),
-                entity=self.properties.get("CompromisedEntity", "unknown"),
-                id=self.properties["SystemAlertId"],
-            )
+            <b>Alert_id:</b> self.properties['SystemAlertId']
+            """
         else:
             title = "Alert has no data."
         return title + super().to_html(show_entities)
