@@ -11,11 +11,12 @@ from datetime import datetime
 from typing import Any, Dict, List, Optional, Union
 
 import pandas as pd
+from deprecated.sphinx import deprecated
 
 from .._version import VERSION
 from ..common.utility import escape_windows_path, export
-from ..data.query_defns import DataEnvironment, DataFamily, QueryParamProvider
-from ..datamodel.entities import Account, Entity, Host, Process
+from ..data.query_defns import DataEnvironment, QueryParamProvider
+from ..datamodel.entities import Account, Entity, Host, Process, OSFamily
 
 __version__ = VERSION
 __author__ = "Ian Hellen"
@@ -37,6 +38,7 @@ _ID_PROPERTIES: List[str] = [
 
 
 # pylint: disable=too-many-public-methods
+@deprecated(reason="Replaced by Alert entity in datamodel", version="1.7.0")
 @export
 class SecurityBase(QueryParamProvider):
     """
@@ -53,7 +55,7 @@ class SecurityBase(QueryParamProvider):
         self._entities: List[Entity] = []
 
         # Extract and cache alert ID properties
-        self._ids: Dict[str, str] = dict()
+        self._ids: Dict[str, str] = {}
         if self._source_data is not None:
             for id_property in _ID_PROPERTIES:
                 if id_property in self._source_data:
@@ -233,7 +235,7 @@ class SecurityBase(QueryParamProvider):
             for proc in procs
             if "ParentProcess" in proc
             and proc["ParentProcess"]
-            and proc["ParentProcess"] in procs
+            and proc.ParentProcess.ProcessId in {proc.ProcessId for proc in procs}
         ]
         return procs_with_parent[0] if procs_with_parent else procs[0]
 
@@ -271,7 +273,7 @@ class SecurityBase(QueryParamProvider):
             )
             acct_name = self.primary_account.Name if self.primary_account else None
             path_separator = self.path_separator
-            if self.data_family == DataFamily.WindowsSecurity:
+            if self.data_family == OSFamily.Windows:
                 proc_name = escape_windows_path(proc_name)
                 path_separator = escape_windows_path(self.path_separator)
 
@@ -297,12 +299,12 @@ class SecurityBase(QueryParamProvider):
             return {}
 
     @property
-    def data_family(self) -> DataFamily:
+    def data_family(self) -> OSFamily:
         """Return the data family of the alert for subsequent queries."""
         if self.os_family == "Linux":
-            return DataFamily.LinuxSecurity
+            return OSFamily.Linux
         if self.os_family == "Windows":
-            return DataFamily.WindowsSecurity
+            return OSFamily.Windows
         raise ValueError("Unknown Data family.")
 
     @property
@@ -356,11 +358,12 @@ class SecurityBase(QueryParamProvider):
         if self.is_in_log_analytics:
             return "true"
         if self.is_in_azure_sub:
-            return "AzureResourceSubscriptionId {} '{}'".format(
-                operator, self._ids["AzSubscriptionId"]
+            return (
+                f"AzureResourceSubscriptionId {operator} "
+                f"'{self._ids['AzSubscriptionId']}'"
             )
         if self.is_in_workspace:
-            return "WorkspaceId {} '{}'".format(operator, self._ids["WorkspaceId"])
+            return f"WorkspaceId {operator} '{self._ids['WorkspaceId']}'"
 
         # Otherwise we default to including everything
         return "true"
@@ -374,24 +377,22 @@ class SecurityBase(QueryParamProvider):
         """
         if self.primary_host:
             case_insens_op = "=~" if operator == "==" else "!~"
-            return "Computer {} '{}'".format(case_insens_op, self.primary_host.computer)
+            return f"Computer {case_insens_op} '{self.primary_host.computer}'"
 
         if (
             self.is_in_log_analytics
             and "SourceComputerId" in self._ids
             and self._ids["SourceComputerId"]
         ):
-            return "SourceComputerId {} '{}'".format(
-                operator, self._ids["SourceComputerId"]
-            )
+            return f"SourceComputerId {operator} '{self._ids['SourceComputerId']}'"
         if (
             self.is_in_azure_sub
             and "AzureResourceId" in self._ids
             and self._ids["AzResourceId"]
         ):
-            return "AzureResourceId {} '{}'".format(operator, self._ids["AzResourceId"])
+            return f"AzureResourceId {operator} '{self._ids['AzResourceId']}'"
         if self.is_in_workspace and "AgendId" in self._ids and self._ids["AgentId"]:
-            return "AgentId {} '{}'".format(operator, self._ids["AgentId"])
+            return f"AgentId {operator} '{self._ids['AgentId']}'"
         return None
 
     def get_entities_of_type(self, entity_type: str) -> List[Entity]:
