@@ -32,7 +32,9 @@ from bokeh.plotting import figure, reset_output
 from bokeh.layouts import column
 
 from .._version import VERSION
+from ..common.exceptions import MsticpyParameterError
 from ..common.utility import export, check_kwargs
+from ..data.query_defns import ensure_df_datetimes
 
 # pylint: disable=unused-import
 # Importing to activate pandas accessors
@@ -77,6 +79,11 @@ _TL_KWARGS = [
     "hide",
 ]
 
+_TIMELINE_HELP = (
+    "https://msticpy.readthedocs.io/en/latest/msticpy.nbtools.html"
+    "#msticpy.nbtools.timeline.{plot_type}"
+)
+
 
 @export
 def display_timeline(
@@ -223,7 +230,7 @@ _TL_VALUE_KWARGS = ["kind", "y", "x"]
 
 # pylint: disable=invalid-name, too-many-locals, too-many-statements, too-many-branches
 @export  # noqa: C901, MC0001
-def display_timeline_values(
+def display_timeline_values(  # noqa: C901, MC0001
     data: pd.DataFrame,
     value_col: str = None,
     time_column: str = "TimeGenerated",
@@ -340,6 +347,10 @@ def display_timeline_values(
         source_columns = [value_col]
     if value_col not in source_columns:
         source_columns.append(value_col)
+    check_df_columns(
+        data, source_columns + [time_column], _TIMELINE_HELP, "display_timeline_values"
+    )
+    data = ensure_df_datetimes(data=data, columns=time_column)
     graph_df, group_count_df, tool_tip_columns, series_count = _create_data_grouping(
         data, source_columns, time_column, group_by, color
     )
@@ -631,6 +642,7 @@ def _plot_series(data, plot, legend_pos):
         legend_pos = "left"
     legend_items = []
     for ser_name, series_def in data.items():
+
         if legend_pos == "inline":
             p_series = plot.diamond(
                 x=series_def["time_column"],
@@ -673,6 +685,38 @@ def _plot_series(data, plot, legend_pos):
         plot.add_layout(ext_legend, legend_pos)
 
 
+def check_df_columns(
+    data: pd.DataFrame, req_columns: List[str], help_uri: str, plot_type: str
+):
+    """
+    Check that specified columns are in the DataFrame.
+
+    Parameters
+    ----------
+    data : pd.DataFrame
+        [description]
+    req_columns : List[str]
+        [description]
+    help_uri : str
+        [description]
+    plot_type : str
+        [description]
+
+    Raises
+    ------
+    MsticpyParameterError
+        If one or more columns not found in `data`
+
+    """
+    missing_cols = set(req_columns) - set(data.columns)
+    if missing_cols:
+        raise MsticpyParameterError(
+            title="Columns not found in DataFrame",
+            help_uri=help_uri.format(plot_type=plot_type),
+            parameter=missing_cols,
+        )
+
+
 def _set_axes_and_grids(data, plot, show_yaxis, ygrid, xgrid):
     """Set the axes visibility and grids according to parameters."""
     plot.yaxis.visible = show_yaxis
@@ -745,6 +789,8 @@ def _unpack_data_series_dict(data, **kwargs):
         if not time_col:
             time_col = time_column
             series_def["time_column"] = time_col
+        # ensure named time columns are in datetime format
+        series_data = ensure_df_datetimes(data=series_data, columns=time_col)
         data_columns.update([time_col])
         # add the data columns to the tool tip column set
         tool_tip_columns.update(data_columns)
@@ -858,7 +904,7 @@ def _create_dict_from_grouping(data, source_columns, time_column, group_by, colo
     return series_dict
 
 
-def _get_ref_event_time(**kwargs) -> Tuple[datetime, str]:
+def _get_ref_event_time(**kwargs) -> Tuple[Optional[Any], Union[Any, str]]:
     """Extract the reference time from kwargs."""
     ref_alert = kwargs.get("alert", None)
     if ref_alert is not None:
@@ -877,7 +923,7 @@ def _get_ref_event_time(**kwargs) -> Tuple[datetime, str]:
     else:
         ref_time = kwargs.get("ref_time", None)
         ref_label = "Ref time"
-    return ref_time, kwargs.get("ref_label", ref_label)
+    return ref_time, kwargs.get("ref_label", ref_label)  # type: ignore
 
 
 def _get_datetime_tooltip(col: str, dataset: pd.DataFrame):
@@ -950,9 +996,7 @@ def _get_tick_formatter() -> DatetimeTickFormatter:
 
 def _calc_auto_plot_height(group_count):
     """Dynamic calculation of plot height."""
-    ht_per_row = 40
-    if group_count > 15:
-        ht_per_row = 25
+    ht_per_row = 25 if group_count > 15 else 40
     return max(ht_per_row * group_count, 300)
 
 
