@@ -79,7 +79,8 @@ def load_user_defaults() -> Dict[str, object]:
 
 def _load_query_providers(user_defaults):
     prov_dict = {}
-    if "QueryProviders" in user_defaults:
+    query_provs = user_defaults.get("QueryProviders", {})
+    if query_provs and isinstance(query_provs, dict):
         for prov_name, qry_prov_entry in user_defaults.get("QueryProviders").items():
             if prov_name == "AzureSentinel":
                 provs = _load_az_workspaces(prov_name, qry_prov_entry)
@@ -246,9 +247,13 @@ def _load_azure_data(comp_settings=None, **kwargs):
 
 def _load_azsent_api(comp_settings=None, **kwargs):
     del kwargs
-    from ..data.azure_sentinel import AzureSentinel
+    from ..data.azure import MicrosoftSentinel
 
-    az_sent = AzureSentinel()
+    res_id = comp_settings.pop("res_id", None)
+    if res_id:
+        az_sent = MicrosoftSentinel(res_id=res_id)
+    else:
+        az_sent = MicrosoftSentinel()
     connect = comp_settings.pop("connect", True)
     connect_args = comp_settings
     if connect:
