@@ -34,11 +34,10 @@ from typing import Any, Dict, List, Mapping, Optional, Tuple
 
 import geoip2.database  # type: ignore
 import pandas as pd
-import requests
+import httpx
 from geoip2.errors import AddressNotFoundError  # type: ignore
 from IPython import get_ipython
 from IPython.display import HTML, display
-from requests.exceptions import HTTPError
 
 from .._version import VERSION
 from ..common.exceptions import MsticpyUserConfigError
@@ -324,7 +323,7 @@ Alternatively, you can pass this to the IPStackLookup class when creating it:
         submit_url = self._IPSTACK_API.format(
             iplist=",".join(ip_list), access_key=self._api_key
         )
-        response = requests.get(submit_url)
+        response = httpx.get(submit_url)
 
         if response.status_code == 200:
             results = response.json()
@@ -334,9 +333,7 @@ Alternatively, you can pass this to the IPStackLookup class when creating it:
 
             if "success" in results and not results["success"]:
                 raise PermissionError(
-                    "Service unable to complete request. Error: {}".format(
-                        results["error"]
-                    )
+                    f"Service unable to complete request. Error: {results['error']}"
                 )
             return [(item, response.status_code) for item in results]
 
@@ -350,12 +347,12 @@ Alternatively, you can pass this to the IPStackLookup class when creating it:
     def _lookup_ip_list(self, ip_list: List[str]):
         """Lookup IP Addresses one-by-one."""
         ip_loc_results = []
-        with requests.Session() as session:
+        with httpx.Client() as client:
             for ip_addr in ip_list:
                 submit_url = self._IPSTACK_API.format(
                     iplist=ip_addr, access_key=self._api_key
                 )
-                response = session.get(submit_url)
+                response = client.get(submit_url)
                 if response.status_code == 200:
                     ip_loc_results.append((response.json(), response.status_code))
                 elif response:
@@ -465,10 +462,110 @@ Alternatively, you can pass this to the GeoLiteLookup class when creating it:
         self._dbfolder = db_folder
         if self._dbfolder is None:
             self._dbfolder = self.settings.args.get("DBFolder", self._DB_HOME)
-
         self._dbfolder = str(Path(self._dbfolder).expanduser())  # type: ignore
         self._force_update = force_update
         self._auto_update = auto_update
+        self._dbpath: Optional[str] = None
+        self._reader: Any = None
+
+    def close(self):
+        """Close an open GeoIP DB."""
+        if self._reader:
+            try:
+                self._reader.close()
+            except Exception as err:  # pylint: disable=broad-except
+                print(f"Exception when trying to close GeoIP DB {err}")
+
+    def lookup_ip(
+        self,
+        ip_address: str = None,
+        ip_addr_list: Iterable = None,
+        ip_entity: IpAddress = None,
+    ) -> Tuple[List[Any], List[IpAddress]]:
+        """
+        Lookup IP location from GeoLite2 data created by MaxMind.
+
+        Parameters
+        ----------
+        ip_address : str, optional
+            a single address to look up (the default is None)
+        ip_addr_list : Iterable, optional
+            a collection of addresses to lookup (the default is None)
+        ip_entity : IpAddress, optional
+            an IpAddress entity (the default is None) - any existing
+            data in the Location property will be overwritten
+
+        Returns
+        -------
+        Tuple[List[Any], List[IpAddress]]
+            raw geolocation results and same results as IpAddress entities with
+            populated Location property.
+
+        """
+        self._check_db_open()
+        if ip_address and isinstance(ip_address, str):
+            ip_list = [ip_address.strip()]
+        elif ip_addr_list:
+            ip_list = [ip.strip() for ip in ip_addr_list]
+        elif ip_entity:
+            ip_list = [ip_entity.Address]
+        else:
+            raise ValueError("No valid ip addresses were passed as arguments.")
+
+        output_raw = []
+        output_entities = []
+        ip_cache: Dict[str, Any] = {}
+        for ip_input in ip_list:
+            geo_match = None
+            try:
+                geo_match = ip_cache.get(ip_input, self._reader.city(ip_input).raw)
+            except (AddressNotFoundError, AttributeError, ValueError):
+                continue
+            if geo_match:
+                output_raw.append(geo_match)
+                output_entities.append(
+                    self._create_ip_entity(ip_input, geo_match, ip_entity)
+                )
+
+        return output_raw, output_entities
+
+    @staticmethod
+    def _create_ip_entity(
+        ip_address: str, geo_match: Mapping[str, Any], ip_entity: IpAddress = None
+    ) -> IpAddress:
+        if not ip_entity:
+            ip_entity = IpAddress()
+            ip_entity.Address = ip_address
+        geo_entity = GeoLocation()
+        geo_entity.CountryCode = geo_match.get("country", {}).get("iso_code", None)
+        geo_entity.CountryName = (
+            geo_match.get("country", {}).get("names", {}).get("en", None)
+        )
+        subdivs = geo_match.get("subdivisions", [])
+        if subdivs:
+            geo_entity.State = subdivs[0].get("names", {}).get("en", None)
+        geo_entity.City = geo_match.get("city", {}).get("names", {}).get("en", None)
+        geo_entity.Longitude = geo_match.get("location", {}).get("longitude", None)
+        geo_entity.Latitude = geo_match.get("location", {}).get("latitude", None)
+        ip_entity.Location = geo_entity
+        return ip_entity
+
+    def _pr_debug(self, *args):
+        """Print out debug info."""
+        if self._debug:
+            print(*args)
+
+    @staticmethod
+    def _geolite_warn(mssg):
+        warnings.warn(
+            f"GeoIpLookup: {mssg}",
+            UserWarning,
+        )
+
+    def _check_db_open(self):
+        """Check if DB reader open with a valid database."""
+        if self._reader:
+            return
         self._check_and_update_db(self._dbfolder, self._force_update, self._auto_update)
         self._dbpath = self._get_geoip_dbpath(self._dbfolder)
         if self._debug:
@@ -510,14 +607,6 @@ Alternatively, you can pass this to the GeoLiteLookup class when creating it:
             )
         self._reader = geoip2.database.Reader(self._dbpath)
 
-    def close(self):
-        """Close an open GeoIP DB."""
-        if self._reader:
-            try:
-                self._reader.close()
-            except Exception as err:  # pylint: disable=broad-except
-                print(f"Exception when trying to close GeoIP DB {err}")
-
     def _check_and_update_db(
         self,
         db_folder: str = None,
@@ -634,16 +723,14 @@ Alternatively, you can pass this to the GeoLiteLookup class when creating it:
             if list(Path(db_folder).glob(self._DB_ARCHIVE.format(rand="*"))):
                 # Some other process is downloading
                 return True
-            with requests.get(url, stream=True) as response:
-                response = requests.get(url, stream=True)
-                response.raise_for_status()
+            with httpx.stream("GET", url) as response:
                 print("Downloading and extracting GeoLite DB archive from MaxMind....")
                 with open(db_archive_path, "wb") as file_hdl:
-                    for chunk in response.iter_content(chunk_size=10000):
+                    for chunk in response.iter_bytes(chunk_size=10000):
                         file_hdl.write(chunk)
                         file_hdl.flush()
             self._pr_debug(f"Downloaded GeoLite DB: {db_archive_path}")
-        except HTTPError as http_err:
+        except httpx.HTTPError as http_err:
             self._pr_debug(
                 f"HTTP error occurred trying to download GeoLite DB: {http_err}"
             )
@@ -744,91 +831,6 @@ Alternatively, you can pass this to the GeoLiteLookup class when creating it:
 
         return latest_db_path
 
-    def lookup_ip(
-        self,
-        ip_address: str = None,
-        ip_addr_list: Iterable = None,
-        ip_entity: IpAddress = None,
-    ) -> Tuple[List[Any], List[IpAddress]]:
-        """
-        Lookup IP location from GeoLite2 data created by MaxMind.
-
-        Parameters
-        ----------
-        ip_address : str, optional
-            a single address to look up (the default is None)
-        ip_addr_list : Iterable, optional
-            a collection of addresses to lookup (the default is None)
-        ip_entity : IpAddress, optional
-            an IpAddress entity (the default is None) - any existing
-            data in the Location property will be overwritten
-
-        Returns
-        -------
-        Tuple[List[Any], List[IpAddress]]
-            raw geolocation results and same results as IpAddress entities with
-            populated Location property.
-
-        """
-        if ip_address and isinstance(ip_address, str):
-            ip_list = [ip_address.strip()]
-        elif ip_addr_list:
-            ip_list = [ip.strip() for ip in ip_addr_list]
-        elif ip_entity:
-            ip_list = [ip_entity.Address]
-        else:
-            raise ValueError("No valid ip addresses were passed as arguments.")
-
-        output_raw = []
-        output_entities = []
-        ip_cache: Dict[str, Any] = {}
-        for ip_input in ip_list:
-            geo_match = None
-            try:
-                geo_match = ip_cache.get(ip_input, self._reader.city(ip_input).raw)
-            except (AddressNotFoundError, AttributeError, ValueError):
-                continue
-            if geo_match:
-                output_raw.append(geo_match)
-                output_entities.append(
-                    self._create_ip_entity(ip_input, geo_match, ip_entity)
-                )
-
-        return output_raw, output_entities
-
-    @staticmethod
-    def _create_ip_entity(
-        ip_address: str, geo_match: Mapping[str, Any], ip_entity: IpAddress = None
-    ) -> IpAddress:
-        if not ip_entity:
-            ip_entity = IpAddress()
-            ip_entity.Address = ip_address
-        geo_entity = GeoLocation()
-        geo_entity.CountryCode = geo_match.get("country", {}).get("iso_code", None)
-        geo_entity.CountryName = (
-            geo_match.get("country", {}).get("names", {}).get("en", None)
-        )
-        subdivs = geo_match.get("subdivisions", [])
-        if subdivs:
-            geo_entity.State = subdivs[0].get("names", {}).get("en", None)
-        geo_entity.City = geo_match.get("city", {}).get("names", {}).get("en", None)
-        geo_entity.Longitude = geo_match.get("location", {}).get("longitude", None)
-        geo_entity.Latitude = geo_match.get("location", {}).get("latitude", None)
-        ip_entity.Location = geo_entity
-        return ip_entity
-
-    def _pr_debug(self, *args):
-        """Print out debug info."""
-        if self._debug:
-            print(*args)
-
-    @staticmethod
-    def _geolite_warn(mssg):
-        warnings.warn(
-            f"GeoIpLookup: {mssg}",
-            UserWarning,
-        )
-
 
 def _get_geoip_provider_settings(provider_name: str) -> ProviderSettings:
     """
