@@ -13,19 +13,20 @@ requests per minute for the account type that you have.
 
 """
 import abc
+import traceback
 from functools import lru_cache
 from http import client
 from json import JSONDecodeError
-import traceback
 from typing import Any, Dict, List, Tuple
 
 import attr
+import httpx
 from attr import Factory
-import requests
 
 from ..._version import VERSION
-from ...common.utility import export
-from .ti_provider_base import LookupResult, TIProvider, TISeverity, TILookupStatus
+from ...common.exceptions import MsticpyConfigException
+from ...common.utility import export, _MSTICPY_USER_AGENT
+from .ti_provider_base import LookupResult, TILookupStatus, TIProvider, TISeverity
 
 __version__ = VERSION
 __author__ = "Ian Hellen"
@@ -61,18 +62,24 @@ class HttpProvider(TIProvider):
         """Initialize a new instance of the class."""
         super().__init__(**kwargs)
 
-        self._requests_session = requests.Session()
+        self._httpx_client = httpx.Client()
         self._request_params = {}
         if "ApiID" in kwargs:
             self._request_params["API_ID"] = kwargs.pop("ApiID")
         if "AuthKey" in kwargs:
             self._request_params["API_KEY"] = kwargs.pop("AuthKey")
 
-        for req_param in self._REQUIRED_PARAMS:
-            if req_param not in self._request_params:
-                raise ValueError(
-                    f"{req_param} value was not found for {self.__class__.__name__}"
-                )
+        missing_params = [
+            param
+            for param in self._REQUIRED_PARAMS
+            if param not in self._request_params
+        ]
+        if missing_params:
+            param_list = ", ".join(f"'{param}'" for param in missing_params)
+            raise MsticpyConfigException(
+                f"Parameter values missing for TI Provider '{self.__class__.__name__}'",
+                f"Missing parameters are: {param_list}",
+            )
 
     # pylint: disable=too-many-branches, duplicate-code
     @lru_cache(maxsize=256)
@@ -123,12 +130,13 @@ class HttpProvider(TIProvider):
         if result.status:
             return result
 
+        req_params: Dict[str, Any] = {}
         try:
             verb, req_params = self._substitute_parms(
                 result.safe_ioc, result.ioc_type, query_type
             )
             if verb == "GET":
-                response = self._requests_session.get(**req_params)
+                response = self._httpx_client.get(**req_params)
             else:
                 raise NotImplementedError(f"Unsupported verb {verb}")
             result.status = response.status_code
@@ -189,28 +197,27 @@ class HttpProvider(TIProvider):
         """
         req_params = {"observable": ioc}
         req_params.update(self._request_params)
-        if query_type:
-            ioc_key = ioc_type + "-" + query_type
-        else:
-            ioc_key = ioc_type
-
+        ioc_key = ioc_type + "-" + query_type if query_type else ioc_type
         src = self._IOC_QUERIES.get(ioc_key, None)
         if not src:
             raise LookupError(f"Provider does not support IoC type {ioc_key}.")
 
         # create a parameter dictionary to pass to requests
-        req_dict: Dict[str, Any] = {}
         # substitute any parameter value from our req_params dict
-        req_dict["url"] = (
-            self._BASE_URL + src.path.format(**req_params)
+        req_dict: Dict[str, Any] = {
+            "headers": {},
+            "url": self._BASE_URL + src.path.format(**req_params)
             if not src.full_url
-            else src.path.format(observable=ioc)
-        )
+            else src.path.format(observable=ioc),
+        }
+
         if src.headers:
             headers: Dict[str, Any] = {
                 key: val.format(**req_params) for key, val in src.headers.items()
             }
             req_dict["headers"] = headers
+        if "User-Agent" not in req_dict["headers"]:
+            req_dict["headers"]["User-Agent"] = _MSTICPY_USER_AGENT
         if src.params:
             q_params: Dict[str, Any] = {
                 key: val.format(**req_params) for key, val in src.params.items()
@@ -222,7 +229,7 @@ class HttpProvider(TIProvider):
             }
             req_dict["data"] = q_data
         if src.auth_type and src.auth_str:
-            auth_strs: Tuple = tuple([p.format(**req_params) for p in src.auth_str])
+            auth_strs: Tuple = tuple(p.format(**req_params) for p in src.auth_str)
             if src.auth_type == "HTTPBasic":
                 req_dict["auth"] = auth_strs
             else:
