@@ -13,7 +13,7 @@ requests per minute for the account type that you have.
 
 """
 import abc
-from abc import ABC
+from abc import ABC, abstractmethod
 import collections
 import math  # noqa
 import pprint
@@ -480,6 +480,28 @@ class TIProvider(ABC):
         return result
 
 
+class TIPivotProvider(ABC):
+    """A class which provides pivot functions and a means of registering them."""
+
+    @abstractmethod
+    def register_pivots(
+        self,
+        pivot_reg: "PivotRegistration",  # type: ignore # noqa: F821
+        pivot: "Pivot",  # type: ignore # noqa: F821
+    ):
+        """
+        Register pivot functions for the TI Provider.
+
+        Parameters
+        ----------
+        pivot_reg : PivotRegistration
+            Pivot registration settings.
+        pivot : Pivot
+            Pivot library instance
+
+        """
+
+
 # slightly stricter than normal URL regex to exclude '() from host string
 _HTTP_STRICT_REGEX = r"""
     (?P<protocol>(https?|ftp|telnet|ldap|file)://)
